"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApp = void 0;
const core_1 = require("@nestjs/core");
const swagger_1 = require("@nestjs/swagger");
const app_module_1 = require("./app.module");
const file_manager_service_1 = require("./infrastructure/services/file-manager/file-manager.service");
const common_1 = require("@nestjs/common");
const telemetry_usecases_1 = require("./usecases/telemetry/telemetry.usecases");
const getApp = async () => {
    const app = await core_1.NestFactory.create(app_module_1.AppModule, {
        snapshot: true,
        cors: true,
        logger: console,
    });
    app.setGlobalPrefix('v1');
    const fileService = app.get(file_manager_service_1.FileManagerService);
    await fileService.getConfig();
    const telemetryService = await app.resolve(telemetry_usecases_1.TelemetryUsecases);
    await telemetryService.initInterval();
    app.useGlobalPipes(new common_1.ValidationPipe({
        transform: true,
        enableDebugMessages: true,
    }));
    const config = new swagger_1.DocumentBuilder()
        .setTitle('Cortex API')
        .setDescription('Cortex API provides a command-line interface (CLI) for seamless interaction with Large Language Models (LLMs). It is fully compatible with the [OpenAI API](https://platform.openai.com/docs/api-reference) and enables straightforward command execution and management of LLM interactions.')
        .setVersion('1.0')
        .addTag('Inference', 'This endpoint initiates interaction with a Large Language Models (LLM).')
        .addTag('Assistants', 'These endpoints manage the lifecycle of an Assistant within a conversation thread.')
        .addTag('Models', 'These endpoints provide a list and descriptions of all available models within the Cortex framework.')
        .addTag('Messages', 'These endpoints manage the retrieval and storage of conversation content, including responses from LLMs and other metadata related to chat interactions.')
        .addTag('Threads', 'These endpoints handle the creation, retrieval, updating, and deletion of conversation threads.')
        .addTag('Embeddings', 'Endpoint for creating and retrieving embedding vectors from text inputs using specified models.')
        .addTag('Status', "Endpoint for actively querying the health status of the Cortex's API server.")
        .addTag('Processes', 'Endpoint for terminating the Cortex API server processes.')
        .addTag('Events', 'Endpoints for observing Cortex statuses through event notifications.')
        .addTag('Configurations', "Endpoints for customizing the Cortex's configurations.")
        .addTag('Engines', 'Endpoints for managing the available engines within Cortex.')
        .addServer('http://localhost:1337')
        .build();
    const document = swagger_1.SwaggerModule.createDocument(app, config);
    swagger_1.SwaggerModule.setup('api', app, document);
    return app;
};
exports.getApp = getApp;
//# sourceMappingURL=app.js.map