#!@@HOMEBREW_PREFIX@@/opt/node/bin/node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ora_1 = __importDefault(require("ora"));
const dependenciesSpinner = (0, ora_1.default)('Loading dependencies...').start();
const time = Date.now();
const nest_commander_1 = require("nest-commander");
const command_module_1 = require("./command.module");
const telemetry_usecases_1 = require("./usecases/telemetry/telemetry.usecases");
const telemetry_interface_1 = require("./domain/telemetry/telemetry.interface");
const context_service_1 = require("./infrastructure/services/context/context.service");
dependenciesSpinner.succeed('Dependencies loaded in ' + (Date.now() - time) + 'ms');
process.removeAllListeners('warning');
async function bootstrap() {
    let telemetryUseCase = null;
    let contextService = null;
    const app = await nest_commander_1.CommandFactory.createWithoutRunning(command_module_1.CommandModule, {
        logger: ['warn', 'error'],
        errorHandler: async (error) => {
            await telemetryUseCase.createCrashReport(error, telemetry_interface_1.TelemetrySource.CLI);
            console.error(error);
            process.exit(1);
        },
        serviceErrorHandler: async (error) => {
            await telemetryUseCase.createCrashReport(error, telemetry_interface_1.TelemetrySource.CLI);
            console.error(error);
            process.exit(1);
        },
    });
    telemetryUseCase = await app.resolve(telemetry_usecases_1.TelemetryUsecases);
    contextService = await app.resolve(context_service_1.ContextService);
    const anonymousData = await telemetryUseCase.updateAnonymousData();
    await contextService.init(async () => {
        contextService.set('source', telemetry_interface_1.TelemetrySource.CLI);
        contextService.set('sessionId', anonymousData === null || anonymousData === void 0 ? void 0 : anonymousData.sessionId);
        telemetryUseCase.sendActivationEvent(telemetry_interface_1.TelemetrySource.CLI);
        telemetryUseCase.sendCrashReport();
        return nest_commander_1.CommandFactory.runApplication(app);
    });
}
bootstrap();
//# sourceMappingURL=command.js.map