"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatCommand = void 0;
const nest_commander_1 = require("nest-commander");
const ora_1 = __importDefault(require("ora"));
const chat_cli_usecases_1 = require("./usecases/chat.cli.usecases");
const node_process_1 = require("node:process");
const ps_cli_usecases_1 = require("./usecases/ps.cli.usecases");
const models_usecases_1 = require("../../usecases/models/models.usecases");
const CommandContext_1 = require("./decorators/CommandContext");
const telemetry_usecases_1 = require("../../usecases/telemetry/telemetry.usecases");
const telemetry_interface_1 = require("../../domain/telemetry/telemetry.interface");
const context_service_1 = require("../services/context/context.service");
let ChatCommand = class ChatCommand extends nest_commander_1.CommandRunner {
    constructor(inquirerService, chatCliUsecases, modelsUsecases, psCliUsecases, contextService, telemetryUsecases) {
        super();
        this.inquirerService = inquirerService;
        this.chatCliUsecases = chatCliUsecases;
        this.modelsUsecases = modelsUsecases;
        this.psCliUsecases = psCliUsecases;
        this.contextService = contextService;
        this.telemetryUsecases = telemetryUsecases;
        this.modelInquiry = async (models) => {
            const { model } = await this.inquirerService.inquirer.prompt({
                type: 'list',
                name: 'model',
                message: 'Select running model to chat with:',
                choices: models.map((e) => ({
                    name: e.modelId,
                    value: e.modelId,
                })),
            });
            return model;
        };
    }
    async run(passedParams, options) {
        var _a, _b;
        let modelId = passedParams[0];
        const checkingSpinner = (0, ora_1.default)('Checking model...').start();
        let message = (_a = options.message) !== null && _a !== void 0 ? _a : passedParams.slice(1).join(' ');
        if (!modelId || !(await this.modelsUsecases.findOne(modelId))) {
            message = passedParams.length
                ? passedParams.join(' ')
                : (_b = options.message) !== null && _b !== void 0 ? _b : '';
            const models = await this.psCliUsecases.getModels();
            if (models.length === 1) {
                modelId = models[0].modelId;
            }
            else if (models.length > 0) {
                modelId = await this.modelInquiry(models);
            }
            else {
                checkingSpinner.fail('Model ID is required');
                (0, node_process_1.exit)(1);
            }
        }
        checkingSpinner.succeed(`Model found`);
        if (!message)
            options.attach = true;
        const result = await this.chatCliUsecases.chat(modelId, options.threadId, message, options.attach, false);
        this.telemetryUsecases.sendEvent([
            {
                name: telemetry_interface_1.EventName.CHAT,
                modelId,
            },
        ], telemetry_interface_1.TelemetrySource.CLI);
        return result;
    }
    parseThreadId(value) {
        return value;
    }
    parseModelId(value) {
        return value;
    }
    parseAttach() {
        return true;
    }
};
exports.ChatCommand = ChatCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-t, --thread <thread_id>',
        description: 'Thread Id. If not provided, will create new thread',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ChatCommand.prototype, "parseThreadId", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-m, --message <message>',
        description: 'Message to send to the model',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ChatCommand.prototype, "parseModelId", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-a, --attach',
        description: 'Attach to interactive chat session',
        defaultValue: false,
        name: 'attach',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], ChatCommand.prototype, "parseAttach", null);
exports.ChatCommand = ChatCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'chat',
        description: 'Send a chat request to a model',
        arguments: '[model_id] [message]',
        argsDescription: {
            model_id: 'Model ID to chat with. If there is no model_id provided, it will prompt to select from running models.',
            message: 'Message to send to the model',
        },
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [nest_commander_1.InquirerService,
        chat_cli_usecases_1.ChatCliUsecases,
        models_usecases_1.ModelsUsecases,
        ps_cli_usecases_1.PSCliUsecases,
        context_service_1.ContextService,
        telemetry_usecases_1.TelemetryUsecases])
], ChatCommand);
//# sourceMappingURL=chat.command.js.map