"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbeddingCommand = void 0;
const nest_commander_1 = require("nest-commander");
const ora_1 = __importDefault(require("ora"));
const models_usecases_1 = require("../../usecases/models/models.usecases");
const ps_cli_usecases_1 = require("./usecases/ps.cli.usecases");
const chat_cli_usecases_1 = require("./usecases/chat.cli.usecases");
const util_1 = require("util");
let EmbeddingCommand = class EmbeddingCommand extends nest_commander_1.CommandRunner {
    constructor(chatCliUsecases, modelsUsecases, psCliUsecases, inquirerService) {
        super();
        this.chatCliUsecases = chatCliUsecases;
        this.modelsUsecases = modelsUsecases;
        this.psCliUsecases = psCliUsecases;
        this.inquirerService = inquirerService;
        this.modelInquiry = async (models) => {
            const { model } = await this.inquirerService.inquirer.prompt({
                type: 'list',
                name: 'model',
                message: 'Select running model to chat with:',
                choices: models.map((e) => ({
                    name: e.modelId,
                    value: e.modelId,
                })),
            });
            return model;
        };
    }
    async run(passedParams, options) {
        var _a;
        let modelId = passedParams[0];
        const checkingSpinner = (0, ora_1.default)('Checking model...').start();
        let input = (_a = options.input) !== null && _a !== void 0 ? _a : passedParams.splice(1);
        if (!modelId || !(await this.modelsUsecases.findOne(modelId))) {
            input = passedParams !== null && passedParams !== void 0 ? passedParams : options.input;
            const models = await this.psCliUsecases.getModels();
            if (models.length === 1) {
                modelId = models[0].modelId;
            }
            else if (models.length > 0) {
                modelId = await this.modelInquiry(models);
            }
            else {
                checkingSpinner.fail('Model ID is required');
                process.exit(1);
            }
        }
        checkingSpinner.succeed(`Model found`);
        return this.chatCliUsecases
            .embeddings(modelId, input)
            .then((res) => (0, util_1.inspect)(res, { showHidden: false, depth: null, colors: true }))
            .then(console.log)
            .catch((e) => { var _a; return console.error((_a = e.message) !== null && _a !== void 0 ? _a : e); });
    }
    parseInput(value) {
        return value;
    }
    parseEncodingFormat(value) {
        return value;
    }
    parseDimensionsFormat(value) {
        return value;
    }
};
exports.EmbeddingCommand = EmbeddingCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-i, --input <input>',
        description: 'Input text to embed, encoded as a string or array of tokens. To embed multiple inputs in a single request, pass an array of strings or array of token arrays.',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], EmbeddingCommand.prototype, "parseInput", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-e, --encoding_format <encoding_format>',
        description: 'Encoding format for the embeddings. Supported formats are float and int.',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], EmbeddingCommand.prototype, "parseEncodingFormat", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-d, --dimensions <dimensions>',
        description: 'The number of dimensions the resulting output embeddings should have. Only supported in some models.',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], EmbeddingCommand.prototype, "parseDimensionsFormat", null);
exports.EmbeddingCommand = EmbeddingCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'embeddings',
        arguments: '[model_id]',
        description: 'Creates an embedding vector representing the input text.',
        argsDescription: {
            model_id: 'Model to use for embedding. If not provided, it will prompt to select from running models.',
        },
    }),
    __metadata("design:paramtypes", [chat_cli_usecases_1.ChatCliUsecases,
        models_usecases_1.ModelsUsecases,
        ps_cli_usecases_1.PSCliUsecases,
        nest_commander_1.InquirerService])
], EmbeddingCommand);
//# sourceMappingURL=embeddings.command.js.map