"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnginesInitCommand = void 0;
const nest_commander_1 = require("nest-commander");
const CommandContext_1 = require("../decorators/CommandContext");
const context_service_1 = require("../../services/context/context.service");
const init_cli_usecases_1 = require("../usecases/init.cli.usecases");
const engine_interface_1 = require("../types/engine.interface");
const cortex_usecases_1 = require("../../../usecases/cortex/cortex.usecases");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
let EnginesInitCommand = class EnginesInitCommand extends nest_commander_1.CommandRunner {
    constructor(initUsecases, cortexUsecases, fileManagerService, contextService) {
        super();
        this.initUsecases = initUsecases;
        this.cortexUsecases = cortexUsecases;
        this.fileManagerService = fileManagerService;
        this.contextService = contextService;
    }
    async run(passedParams) {
        const engine = passedParams[0];
        const options = passedParams.includes(engine_interface_1.Engines.llamaCPP)
            ? await this.initUsecases.defaultInstallationOptions()
            : {};
        const configs = await this.fileManagerService.getConfig();
        const host = configs.cortexCppHost;
        const port = configs.cortexCppPort;
        if (await this.cortexUsecases.healthCheck(host, port)) {
            await this.cortexUsecases.stopCortex();
        }
        return this.initUsecases
            .installEngine(options, engine.includes('@') ? engine.split('@')[1] : 'latest', engine, true)
            .then(() => console.log('Engine installed successfully!'))
            .catch((e) => { var _a; return console.error('Install engine failed with reason: %s', (_a = e.message) !== null && _a !== void 0 ? _a : e); });
    }
};
exports.EnginesInitCommand = EnginesInitCommand;
exports.EnginesInitCommand = EnginesInitCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'init',
        description: 'Setup engine',
        arguments: '<name>',
        argsDescription: {
            name: 'Engine name to setup',
        },
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [init_cli_usecases_1.InitCliUsecases,
        cortex_usecases_1.CortexUsecases,
        file_manager_service_1.FileManagerService,
        context_service_1.ContextService])
], EnginesInitCommand);
//# sourceMappingURL=engines-init.command.js.map