"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitCommand = void 0;
const nest_commander_1 = require("nest-commander");
const init_cli_usecases_1 = require("./usecases/init.cli.usecases");
const CommandContext_1 = require("./decorators/CommandContext");
const telemetry_usecases_1 = require("../../usecases/telemetry/telemetry.usecases");
const telemetry_interface_1 = require("../../domain/telemetry/telemetry.interface");
const context_service_1 = require("../services/context/context.service");
let InitCommand = class InitCommand extends nest_commander_1.CommandRunner {
    constructor(inquirerService, initUsecases, contextService, telemetryUsecases) {
        super();
        this.inquirerService = inquirerService;
        this.initUsecases = initUsecases;
        this.contextService = contextService;
        this.telemetryUsecases = telemetryUsecases;
    }
    async run(passedParams, options) {
        var _a;
        if (options === null || options === void 0 ? void 0 : options.silent) {
            await this.initUsecases.installEngine(undefined);
        }
        else {
            options = await this.inquirerService.ask('init-run-mode-questions', options);
            const version = (_a = passedParams[0]) !== null && _a !== void 0 ? _a : 'latest';
            await this.initUsecases.installEngine(options, version);
            this.telemetryUsecases.sendEvent([
                {
                    name: telemetry_interface_1.EventName.INIT,
                },
            ], telemetry_interface_1.TelemetrySource.CLI);
        }
        console.log('Cortex engines installed successfully!');
    }
    parseSilent() {
        return true;
    }
};
exports.InitCommand = InitCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-s, --silent',
        description: 'Init without asking questions',
        defaultValue: false,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], InitCommand.prototype, "parseSilent", null);
exports.InitCommand = InitCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'init',
        aliases: ['setup'],
        arguments: '[version]',
        description: "Init settings and download cortex's dependencies",
        argsDescription: {
            version: 'Version of cortex engine',
        },
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [nest_commander_1.InquirerService,
        init_cli_usecases_1.InitCliUsecases,
        context_service_1.ContextService,
        telemetry_usecases_1.TelemetryUsecases])
], InitCommand);
//# sourceMappingURL=init.command.js.map