"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelPullCommand = void 0;
const nest_commander_1 = require("nest-commander");
const node_process_1 = require("node:process");
const CommandContext_1 = require("../decorators/CommandContext");
const models_cli_usecases_1 = require("../usecases/models.cli.usecases");
const model_not_found_exception_1 = require("../../exception/model-not-found.exception");
const telemetry_usecases_1 = require("../../../usecases/telemetry/telemetry.usecases");
const telemetry_interface_1 = require("../../../domain/telemetry/telemetry.interface");
const context_service_1 = require("../../services/context/context.service");
const fs_1 = require("fs");
const node_path_1 = require("node:path");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const init_cli_usecases_1 = require("../usecases/init.cli.usecases");
const model_check_1 = require("../../../utils/model-check");
const engine_interface_1 = require("../types/engine.interface");
let ModelPullCommand = class ModelPullCommand extends nest_commander_1.CommandRunner {
    constructor(modelsCliUsecases, initUsecases, fileService, contextService, telemetryUsecases) {
        super();
        this.modelsCliUsecases = modelsCliUsecases;
        this.initUsecases = initUsecases;
        this.fileService = fileService;
        this.contextService = contextService;
        this.telemetryUsecases = telemetryUsecases;
    }
    async run(passedParams) {
        if (passedParams.length < 1) {
            console.error('Model Id is required');
            (0, node_process_1.exit)(1);
        }
        const modelId = passedParams[0];
        await (0, model_check_1.checkModelCompatibility)(modelId);
        await this.modelsCliUsecases.pullModel(modelId).catch((e) => {
            var _a;
            if (e instanceof model_not_found_exception_1.ModelNotFoundException)
                console.error('Model does not exist.');
            else
                console.error((_a = e.message) !== null && _a !== void 0 ? _a : e);
            (0, node_process_1.exit)(1);
        });
        const existingModel = await this.modelsCliUsecases.getModel(modelId);
        const engine = (existingModel === null || existingModel === void 0 ? void 0 : existingModel.engine) || engine_interface_1.Engines.llamaCPP;
        if (!(0, fs_1.existsSync)((0, node_path_1.join)(await this.fileService.getCortexCppEnginePath(), engine))) {
            console.log('\n');
            await this.initUsecases.installEngine(undefined, 'latest', engine);
        }
        this.telemetryUsecases.sendEvent([
            {
                name: telemetry_interface_1.EventName.DOWNLOAD_MODEL,
                modelId: passedParams[0],
            },
        ], telemetry_interface_1.TelemetrySource.CLI);
        console.log('\nDownload complete!');
        (0, node_process_1.exit)(0);
    }
};
exports.ModelPullCommand = ModelPullCommand;
exports.ModelPullCommand = ModelPullCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'pull',
        aliases: ['download'],
        arguments: '<model_id>',
        argsDescription: { model_id: 'Model repo to pull' },
        description: 'Download a model from a registry. Working with HuggingFace repositories. For available models, please visit https://huggingface.co/cortexso',
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [models_cli_usecases_1.ModelsCliUsecases,
        init_cli_usecases_1.InitCliUsecases,
        file_manager_service_1.FileManagerService,
        context_service_1.ContextService,
        telemetry_usecases_1.TelemetryUsecases])
], ModelPullCommand);
//# sourceMappingURL=model-pull.command.js.map