"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelStartCommand = void 0;
const nest_commander_1 = require("nest-commander");
const ora_1 = __importDefault(require("ora"));
const node_process_1 = require("node:process");
const models_cli_usecases_1 = require("../usecases/models.cli.usecases");
const cortex_usecases_1 = require("../../../usecases/cortex/cortex.usecases");
const CommandContext_1 = require("../decorators/CommandContext");
const context_service_1 = require("../../services/context/context.service");
const init_cli_usecases_1 = require("../usecases/init.cli.usecases");
const node_fs_1 = require("node:fs");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const node_path_1 = require("node:path");
const engine_interface_1 = require("../types/engine.interface");
const model_check_1 = require("../../../utils/model-check");
let ModelStartCommand = class ModelStartCommand extends nest_commander_1.CommandRunner {
    constructor(inquirerService, cortexUsecases, modelsCliUsecases, initUsecases, fileService, contextService) {
        super();
        this.inquirerService = inquirerService;
        this.cortexUsecases = cortexUsecases;
        this.modelsCliUsecases = modelsCliUsecases;
        this.initUsecases = initUsecases;
        this.fileService = fileService;
        this.contextService = contextService;
        this.modelInquiry = async () => {
            const models = await this.modelsCliUsecases.listAllModels();
            if (!models.length)
                throw 'No models found';
            const { model } = await this.inquirerService.inquirer.prompt({
                type: 'list',
                name: 'model',
                message: 'Select a model to start:',
                choices: models.map((e) => ({
                    name: e.name,
                    value: e.model,
                })),
            });
            return model;
        };
    }
    async run(passedParams, options) {
        let modelId = passedParams[0];
        const checkingSpinner = (0, ora_1.default)('Checking model...').start();
        if (!modelId) {
            try {
                modelId = await this.modelInquiry();
            }
            catch (_a) {
                checkingSpinner.fail('Model ID is required');
                (0, node_process_1.exit)(1);
            }
        }
        const existingModel = await this.modelsCliUsecases.getModel(modelId);
        if (!existingModel ||
            !Array.isArray(existingModel.files) ||
            /^(http|https):\/\/[^/]+\/.*/.test(existingModel.files[0])) {
            checkingSpinner.fail(`Model ${modelId} not found on filesystem.\nPlease try 'cortex pull ${modelId}' first.`);
            process.exit(1);
        }
        await (0, model_check_1.checkModelCompatibility)(modelId);
        checkingSpinner.succeed('Model found');
        const engine = existingModel.engine || engine_interface_1.Engines.llamaCPP;
        if (!(0, node_fs_1.existsSync)((0, node_path_1.join)(await this.fileService.getCortexCppEnginePath(), engine))) {
            const engineSpinner = (0, ora_1.default)('Installing engine...').start();
            await this.initUsecases.installEngine(undefined, 'latest', engine);
            engineSpinner.succeed();
        }
        if (options.attach) {
            this.attachLogWatch();
        }
        await this.cortexUsecases
            .startCortex()
            .then(() => this.modelsCliUsecases.startModel(modelId, options.preset))
            .then(() => options.attach && (0, ora_1.default)('Model is running...').start());
    }
    parseAttach() {
        return true;
    }
    parseTemplate(value) {
        return value;
    }
    async attachLogWatch() {
        const logPath = await this.fileService.getLogPath();
        const initialSize = (0, node_fs_1.statSync)(logPath).size;
        const logStream = (0, node_fs_1.createReadStream)(logPath, {
            start: initialSize,
            encoding: 'utf-8',
            autoClose: false,
        });
        logStream.on('data', (chunk) => {
            console.log(chunk);
        });
        (0, node_fs_1.watchFile)(logPath, (curr, prev) => {
            if (curr.size > prev.size) {
                const position = prev.size;
                const updateStream = (0, node_fs_1.createReadStream)(logPath, {
                    encoding: 'utf8',
                    start: position,
                });
                updateStream.on('data', (chunk) => {
                    console.log(chunk);
                });
            }
        });
    }
};
exports.ModelStartCommand = ModelStartCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-a, --attach',
        description: 'Attach to interactive chat session',
        defaultValue: false,
        name: 'attach',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], ModelStartCommand.prototype, "parseAttach", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-p, --preset <preset>',
        description: 'Apply a chat preset to the chat session',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelStartCommand.prototype, "parseTemplate", null);
exports.ModelStartCommand = ModelStartCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'start',
        description: 'Start a model by ID.',
        arguments: '[model_id]',
        argsDescription: {
            model_id: 'Model ID to start. If there is no model ID, it will prompt you to select from the available models.',
        },
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [nest_commander_1.InquirerService,
        cortex_usecases_1.CortexUsecases,
        models_cli_usecases_1.ModelsCliUsecases,
        init_cli_usecases_1.InitCliUsecases,
        file_manager_service_1.FileManagerService,
        context_service_1.ContextService])
], ModelStartCommand);
//# sourceMappingURL=model-start.command.js.map