"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelUpdateCommand = void 0;
const nest_commander_1 = require("nest-commander");
const models_cli_usecases_1 = require("../usecases/models.cli.usecases");
const node_process_1 = require("node:process");
const CommandContext_1 = require("../decorators/CommandContext");
const context_service_1 = require("../../services/context/context.service");
let ModelUpdateCommand = class ModelUpdateCommand extends nest_commander_1.CommandRunner {
    constructor(modelsCliUsecases, contextService) {
        super();
        this.modelsCliUsecases = modelsCliUsecases;
        this.contextService = contextService;
    }
    async run(passedParams, option) {
        const modelId = option.model;
        if (!modelId) {
            console.error('Model Id is required');
            (0, node_process_1.exit)(1);
        }
        const options = option.options;
        if (!options || options.length === 0) {
            console.log('Nothing to update');
            (0, node_process_1.exit)(0);
        }
        const toUpdate = {};
        options.forEach((option) => {
            const [key, stringValue] = option.split('=');
            Object.assign(toUpdate, { key, stringValue });
        });
        this.modelsCliUsecases.updateModel(modelId, toUpdate);
    }
    parseModelId(value) {
        return value;
    }
    parseOptions(option, optionsAccumulator = []) {
        optionsAccumulator.push(option);
        return optionsAccumulator;
    }
};
exports.ModelUpdateCommand = ModelUpdateCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-m, --model <model_id>',
        required: true,
        description: 'Model Id to update',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelUpdateCommand.prototype, "parseModelId", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-c, --options <options...>',
        description: 'Specify the options to update the model. Syntax: -c option1=value1 option2=value2. For example: cortex models update -c max_tokens=100 temperature=0.5',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array]),
    __metadata("design:returntype", Array)
], ModelUpdateCommand.prototype, "parseOptions", null);
exports.ModelUpdateCommand = ModelUpdateCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'update',
        description: 'Update configuration of a model.',
        arguments: '<model_id>',
        argsDescription: {
            model_id: 'Model ID to update configuration.',
        },
    }),
    (0, CommandContext_1.SetCommandContext)(),
    __metadata("design:paramtypes", [models_cli_usecases_1.ModelsCliUsecases,
        context_service_1.ContextService])
], ModelUpdateCommand);
//# sourceMappingURL=model-update.command.js.map