"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunCommand = void 0;
const cortex_usecases_1 = require("../../../usecases/cortex/cortex.usecases");
const nest_commander_1 = require("nest-commander");
const node_process_1 = require("node:process");
const ora_1 = __importDefault(require("ora"));
const chat_cli_usecases_1 = require("../usecases/chat.cli.usecases");
const models_cli_usecases_1 = require("../usecases/models.cli.usecases");
const model_not_found_exception_1 = require("../../exception/model-not-found.exception");
const fs_1 = require("fs");
const path_1 = require("path");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const init_cli_usecases_1 = require("../usecases/init.cli.usecases");
const engine_interface_1 = require("../types/engine.interface");
const model_check_1 = require("../../../utils/model-check");
let RunCommand = class RunCommand extends nest_commander_1.CommandRunner {
    constructor(modelsCliUsecases, cortexUsecases, chatCliUsecases, inquirerService, fileService, initUsecases) {
        super();
        this.modelsCliUsecases = modelsCliUsecases;
        this.cortexUsecases = cortexUsecases;
        this.chatCliUsecases = chatCliUsecases;
        this.inquirerService = inquirerService;
        this.fileService = fileService;
        this.initUsecases = initUsecases;
        this.modelInquiry = async () => {
            const models = await this.modelsCliUsecases.listAllModels();
            if (!models.length)
                throw 'No models found';
            const { model } = await this.inquirerService.inquirer.prompt({
                type: 'list',
                name: 'model',
                message: 'Select a model to start:',
                choices: models.map((e) => ({
                    name: e.name,
                    value: e.model,
                })),
            });
            return model;
        };
    }
    async run(passedParams, options) {
        let modelId = passedParams[0];
        const checkingSpinner = (0, ora_1.default)('Checking model...').start();
        if (!modelId) {
            try {
                modelId = await this.modelInquiry();
            }
            catch (_a) {
                checkingSpinner.fail('Model ID is required');
                (0, node_process_1.exit)(1);
            }
        }
        await (0, model_check_1.checkModelCompatibility)(modelId, checkingSpinner);
        if (!(await this.modelsCliUsecases.getModel(modelId))) {
            checkingSpinner.succeed();
            await this.modelsCliUsecases.pullModel(modelId).catch((e) => {
                var _a;
                if (e instanceof model_not_found_exception_1.ModelNotFoundException)
                    checkingSpinner.fail('Model does not exist.');
                else
                    checkingSpinner.fail((_a = e.message) !== null && _a !== void 0 ? _a : e);
                (0, node_process_1.exit)(1);
            });
        }
        const existingModel = await this.modelsCliUsecases.getModel(modelId);
        if (!existingModel ||
            !Array.isArray(existingModel.files) ||
            /^(http|https):\/\/[^/]+\/.*/.test(existingModel.files[0])) {
            checkingSpinner.fail(`Model is not available`);
            process.exit(1);
        }
        checkingSpinner.succeed('Model found');
        const engine = existingModel.engine || engine_interface_1.Engines.llamaCPP;
        if (!(0, fs_1.existsSync)((0, path_1.join)(await this.fileService.getCortexCppEnginePath(), engine))) {
            const engineSpinner = (0, ora_1.default)('Installing engine...').start();
            await this.initUsecases.installEngine(undefined, 'latest', engine);
            engineSpinner.succeed('Engine installed');
        }
        return this.cortexUsecases
            .startCortex()
            .then(() => this.modelsCliUsecases.startModel(modelId, options.preset))
            .then(() => this.chatCliUsecases.chat(modelId, options.threadId));
    }
    parseThreadId(value) {
        return value;
    }
    parseTemplate(value) {
        return value;
    }
};
exports.RunCommand = RunCommand;
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-t, --thread <thread_id>',
        description: 'Thread Id. If not provided, will create new thread',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], RunCommand.prototype, "parseThreadId", null);
__decorate([
    (0, nest_commander_1.Option)({
        flags: '-p, --preset <preset>',
        description: 'Apply a chat preset to the chat session',
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], RunCommand.prototype, "parseTemplate", null);
exports.RunCommand = RunCommand = __decorate([
    (0, nest_commander_1.SubCommand)({
        name: 'run',
        arguments: '[model_id]',
        argsDescription: {
            model_id: 'Model to run. If the model is not available, it will attempt to pull.',
        },
        description: 'Shortcut to start a model and chat',
    }),
    __metadata("design:paramtypes", [models_cli_usecases_1.ModelsCliUsecases,
        cortex_usecases_1.CortexUsecases,
        chat_cli_usecases_1.ChatCliUsecases,
        nest_commander_1.InquirerService,
        file_manager_service_1.FileManagerService,
        init_cli_usecases_1.InitCliUsecases])
], RunCommand);
//# sourceMappingURL=run.command.js.map