"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BenchmarkCliUsecases = void 0;
const common_1 = require("@nestjs/common");
const systeminformation_1 = __importDefault(require("systeminformation"));
const fs_1 = __importStar(require("fs"));
const cortexso_node_1 = __importDefault(require("cortexso-node"));
const cli_progress_1 = require("cli-progress");
const js_yaml_1 = __importDefault(require("js-yaml"));
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const path_1 = require("path");
const models_cli_usecases_1 = require("./models.cli.usecases");
const child_process_1 = require("child_process");
const cortex_usecases_1 = require("../../../usecases/cortex/cortex.usecases");
const util_1 = require("util");
const benchmark_1 = require("../../constants/benchmark");
const ps_cli_usecases_1 = require("./ps.cli.usecases");
const telemetry_usecases_1 = require("../../../usecases/telemetry/telemetry.usecases");
let BenchmarkCliUsecases = class BenchmarkCliUsecases {
    constructor(modelsCliUsecases, cortexUsecases, fileService, psUsecases, telemetryUsecases) {
        this.modelsCliUsecases = modelsCliUsecases;
        this.cortexUsecases = cortexUsecases;
        this.fileService = fileService;
        this.psUsecases = psUsecases;
        this.telemetryUsecases = telemetryUsecases;
    }
    async benchmark(options, params) {
        return this.getBenchmarkConfig().then((config) => {
            var _a;
            this.config = {
                ...config,
                ...options,
            };
            const modelId = (_a = params === null || params === void 0 ? void 0 : params.model) !== null && _a !== void 0 ? _a : this.config.api.parameters.model;
            this.cortexClient = new cortexso_node_1.default({
                apiKey: this.config.api.api_key,
                baseURL: this.config.api.base_url,
                timeout: 20 * 1000,
            });
            const serveProcess = (0, child_process_1.spawn)('cortex', ['serve'], {
                detached: false,
                shell: process.platform == 'win32',
            });
            return this.cortexUsecases
                .startCortex()
                .then(() => this.modelsCliUsecases.startModel(modelId))
                .then(() => this.psUsecases
                .getModels()
                .then((models) => models.find((e) => e.modelId === modelId)))
                .then((model) => {
                if (!model)
                    throw new Error('Model is not started, please try again!');
                return model;
            })
                .then((model) => this.runBenchmarks(model))
                .then(() => {
                serveProcess.kill();
                process.exit(0);
            });
        });
    }
    async getBenchmarkConfig() {
        const benchmarkFolder = await this.fileService.getBenchmarkPath();
        const configurationPath = (0, path_1.join)(benchmarkFolder, 'config.yaml');
        if ((0, fs_1.existsSync)(configurationPath)) {
            return js_yaml_1.default.load((0, fs_1.readFileSync)(configurationPath, 'utf8'));
        }
        else {
            const config = js_yaml_1.default.dump(benchmark_1.defaultBenchmarkConfiguration);
            if (!(0, fs_1.existsSync)(benchmarkFolder)) {
                (0, fs_1.mkdirSync)(benchmarkFolder, {
                    recursive: true,
                });
            }
            await (0, fs_1.writeFileSync)(configurationPath, config, 'utf8');
            return benchmark_1.defaultBenchmarkConfiguration;
        }
    }
    async getSystemResources() {
        return {
            cpuLoad: await systeminformation_1.default.currentLoad(),
            mem: await systeminformation_1.default.mem(),
            gpu: (await systeminformation_1.default.graphics()).controllers,
            cpu: await systeminformation_1.default.cpu(),
            board: await systeminformation_1.default.baseboard(),
            disk: await systeminformation_1.default.diskLayout(),
            chassis: await systeminformation_1.default.chassis(),
            memLayout: await systeminformation_1.default.memLayout(),
            os: await systeminformation_1.default.osInfo(),
        };
    }
    async getResourceChange(startData, endData) {
        return {
            cpuLoad: startData.cpuLoad && endData.cpuLoad
                ? ((endData.cpuLoad.currentLoad - startData.cpuLoad.currentLoad) /
                    startData.cpuLoad.currentLoad) *
                    100
                : null,
            mem: startData.mem && endData.mem
                ? ((endData.mem.used - startData.mem.used) / startData.mem.total) *
                    100
                : null,
        };
    }
    async benchmarkUser(model) {
        var _a, _b, _c, _d;
        const startResources = await this.getSystemResources();
        const start = Date.now();
        let tokenCount = 0;
        let firstTokenTime = null;
        try {
            const stream = await this.cortexClient.chat.completions.create({
                model: model.modelId,
                messages: this.config.api.parameters.messages,
                max_tokens: this.config.api.parameters.max_tokens,
                stream: true,
            });
            for await (const chunk of stream) {
                if (!firstTokenTime && ((_b = (_a = chunk.choices[0]) === null || _a === void 0 ? void 0 : _a.delta) === null || _b === void 0 ? void 0 : _b.content)) {
                    firstTokenTime = Date.now();
                }
                tokenCount += (((_d = (_c = chunk.choices[0]) === null || _c === void 0 ? void 0 : _c.delta) === null || _d === void 0 ? void 0 : _d.content) || '').split(/\s+/).length;
            }
        }
        catch (error) {
            console.error('Error during API call:', error);
            return null;
        }
        const latency = Date.now() - start;
        const ttft = firstTokenTime ? firstTokenTime - start : null;
        const endResources = await this.getSystemResources();
        const resourceChange = await this.getResourceChange(startResources, endResources);
        return {
            tokens: this.config.api.parameters.max_tokens,
            token_length: tokenCount,
            latency,
            resourceChange,
            tpot: tokenCount ? latency / tokenCount : 0,
            throughput: tokenCount / (latency / 1000),
            ttft,
        };
    }
    calculatePercentiles(data, percentile) {
        if (data.length === 0)
            return null;
        const sorted = data
            .filter((x) => x !== null)
            .sort((a, b) => a - b);
        const pos = (percentile / 100) * sorted.length;
        if (pos < 1)
            return sorted[0];
        if (pos >= sorted.length)
            return sorted[sorted.length - 1];
        const lower = sorted[Math.floor(pos) - 1];
        const upper = sorted[Math.ceil(pos) - 1];
        return lower + (upper - lower) * (pos - Math.floor(pos));
    }
    async runBenchmarks(model) {
        const allResults = [];
        const rounds = this.config.num_rounds || 1;
        const bar = new cli_progress_1.SingleBar({}, cli_progress_1.Presets.shades_classic);
        bar.start(rounds, 0);
        for (let i = 0; i < rounds; i++) {
            const roundResults = [];
            const hardwareBefore = await this.getSystemResources();
            for (let j = 0; j < this.config.concurrency; j++) {
                const result = await this.benchmarkUser(model);
                if (result) {
                    roundResults.push(result);
                }
            }
            const hardwareAfter = await this.getSystemResources();
            const hardwareChanges = await this.getResourceChange(hardwareBefore, hardwareAfter);
            allResults.push({
                round: i + 1,
                results: roundResults,
                hardwareChanges,
            });
            bar.update(i + 1);
        }
        const metrics = {
            p50: {},
            p75: {},
            p95: {},
        };
        const keys = ['latency', 'tpot', 'throughput', 'ttft'];
        keys.forEach((key) => {
            const data = allResults.flatMap((r) => r.results.map((res) => res[key]));
            metrics.p50[key] = this.calculatePercentiles(data, 50);
            metrics.p75[key] = this.calculatePercentiles(data, 75);
            metrics.p95[key] = this.calculatePercentiles(data, 95);
        });
        const output = {
            hardware: await this.getSystemResources(),
            results: allResults,
            metrics,
            model,
        };
        bar.stop();
        const outputFilePath = (0, path_1.join)(await this.fileService.getBenchmarkPath(), 'output.json');
        await this.telemetryUsecases.sendBenchmarkEvent({
            hardware: {
                cpu: output.hardware.cpu,
                gpu: output.hardware.gpu,
                memLayout: output.hardware.memLayout,
                board: output.hardware.board,
                disk: output.hardware.disk,
                chassis: output.hardware.chassis,
                os: output.hardware.os,
            },
            results: output.results,
            metrics: output.metrics,
            model,
        });
        fs_1.default.writeFileSync(outputFilePath, JSON.stringify(output, null, 2));
        console.log(`Benchmark results and metrics saved to ${outputFilePath}`);
        if (this.config.output === 'table') {
            console.log('Results:');
            output.results.forEach((round) => {
                console.log('Round ' + round.round + ':');
                console.table(round.results);
            });
            console.log('Metrics:');
            console.table(output.metrics);
        }
        else
            console.log((0, util_1.inspect)(output, {
                showHidden: false,
                depth: null,
                colors: true,
            }));
    }
};
exports.BenchmarkCliUsecases = BenchmarkCliUsecases;
exports.BenchmarkCliUsecases = BenchmarkCliUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [models_cli_usecases_1.ModelsCliUsecases,
        cortex_usecases_1.CortexUsecases,
        file_manager_service_1.FileManagerService,
        ps_cli_usecases_1.PSCliUsecases,
        telemetry_usecases_1.TelemetryUsecases])
], BenchmarkCliUsecases);
//# sourceMappingURL=benchmark.cli.usecases.js.map