"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatCliUsecases = void 0;
const node_process_1 = require("node:process");
const readline = __importStar(require("node:readline/promises"));
const common_1 = require("@nestjs/common");
const threads_usecases_1 = require("../../../usecases/threads/threads.usecases");
const assistants_usecases_1 = require("../../../usecases/assistants/assistants.usecases");
const models_usecases_1 = require("../../../usecases/models/models.usecases");
const messages_usecases_1 = require("../../../usecases/messages/messages.usecases");
const model_parameter_parser_1 = require("../../../utils/model-parameter.parser");
const chat_usecases_1 = require("../../../usecases/chat/chat.usecases");
let ChatCliUsecases = class ChatCliUsecases {
    constructor(assistantUsecases, threadUsecases, chatUsecases, modelsUsecases, messagesUsecases) {
        this.assistantUsecases = assistantUsecases;
        this.threadUsecases = threadUsecases;
        this.chatUsecases = chatUsecases;
        this.modelsUsecases = modelsUsecases;
        this.messagesUsecases = messagesUsecases;
        this.exitClause = 'exit()';
        this.userIndicator = '>> ';
        this.exitMessage = 'Bye!';
    }
    async chat(modelId, threadId, message, attach = true, stopModel = true) {
        if (attach)
            console.log(`In order to exit, type '${this.exitClause}'.`);
        const thread = await this.getOrCreateNewThread(modelId, threadId);
        const messages = (await this.messagesUsecases.getLastMessagesByThread(thread.id, 10)).map((message) => ({
            content: message.content[0].text.value,
            role: message.role,
        }));
        const rl = readline.createInterface({
            input: node_process_1.stdin,
            output: node_process_1.stdout,
            prompt: this.userIndicator,
        });
        if (message)
            sendCompletionMessage.bind(this)(message);
        if (attach)
            rl.prompt();
        rl.on('close', async () => {
            if (stopModel)
                await this.modelsUsecases.stopModel(modelId);
            if (attach)
                console.log(this.exitMessage);
            (0, node_process_1.exit)(0);
        });
        rl.on('line', sendCompletionMessage.bind(this));
        async function sendCompletionMessage(userInput) {
            if (!userInput || userInput.trim() === '')
                return;
            if (userInput.trim() === this.exitClause) {
                rl.close();
                return;
            }
            const model = await this.modelsUsecases.findOne(modelId);
            messages.push({
                content: userInput,
                role: 'user',
            });
            const createMessageDto = {
                thread_id: thread.id,
                role: 'user',
                content: [
                    {
                        type: 'text',
                        text: {
                            value: userInput,
                            annotations: [],
                        },
                    },
                ],
                status: 'completed',
            };
            this.messagesUsecases.create(createMessageDto);
            const parser = new model_parameter_parser_1.ModelParameterParser();
            const chatDto = {
                messages,
                model: modelId,
                stream: true,
                max_tokens: 4098,
                temperature: 0.7,
                ...parser.parseModelInferenceParams(model),
            };
            const decoder = new TextDecoder('utf-8');
            this.chatUsecases
                .inference(chatDto, {})
                .then((response) => {
                var _a, _b, _c;
                if (!chatDto.stream) {
                    const objectData = response;
                    const assistantResponse = (_c = (_b = (_a = objectData.choices[0]) === null || _a === void 0 ? void 0 : _a.message) === null || _b === void 0 ? void 0 : _b.content) !== null && _c !== void 0 ? _c : '';
                    node_process_1.stdout.write(assistantResponse);
                    messages.push({
                        content: assistantResponse,
                        role: 'assistant',
                    });
                    const createMessageDto = {
                        thread_id: thread.id,
                        role: 'assistant',
                        content: [
                            {
                                type: 'text',
                                text: {
                                    value: assistantResponse,
                                    annotations: [],
                                },
                            },
                        ],
                        status: 'completed',
                    };
                    this.messagesUsecases.create(createMessageDto).then(() => {
                        console.log('\n');
                        if (attach)
                            rl.prompt();
                        else
                            rl.close();
                    });
                    return;
                }
                let assistantResponse = '';
                response.on('error', (error) => {
                    var _a;
                    console.error((_a = error.message) !== null && _a !== void 0 ? _a : error);
                    if (attach)
                        rl.prompt();
                    else
                        rl.close();
                });
                response.on('end', () => {
                    messages.push({
                        content: assistantResponse,
                        role: 'assistant',
                    });
                    const createMessageDto = {
                        thread_id: thread.id,
                        role: 'assistant',
                        content: [
                            {
                                type: 'text',
                                text: {
                                    value: assistantResponse,
                                    annotations: [],
                                },
                            },
                        ],
                        status: 'completed',
                    };
                    this.messagesUsecases.create(createMessageDto).then(() => {
                        assistantResponse = '';
                        console.log('\n');
                        if (attach)
                            rl.prompt();
                        else
                            rl.close();
                    });
                });
                response.on('data', (chunk) => {
                    var _a, _b, _c;
                    let content = '';
                    const text = decoder.decode(chunk);
                    const lines = text.trim().split('\n');
                    let cachedLines = '';
                    for (const line of lines) {
                        try {
                            const toParse = cachedLines + line;
                            if (!line.includes('data: [DONE]')) {
                                const data = JSON.parse(toParse.replace('data: ', ''));
                                content = (_c = (_b = (_a = data.choices[0]) === null || _a === void 0 ? void 0 : _a.delta) === null || _b === void 0 ? void 0 : _b.content) !== null && _c !== void 0 ? _c : '';
                                if (content.startsWith('assistant: ')) {
                                    content = content.replace('assistant: ', '');
                                }
                                if (content.trim().length > 0) {
                                    assistantResponse += content;
                                    node_process_1.stdout.write(content);
                                }
                            }
                        }
                        catch (_d) {
                            cachedLines = line;
                        }
                    }
                });
            })
                .catch((e) => {
                node_process_1.stdout.write(`Something went wrong! Please check model status.\n${e.message}\n`);
                if (attach)
                    rl.prompt();
                else
                    rl.close();
            });
        }
    }
    embeddings(model, input, encoding_format = 'float', dimensions) {
        return this.chatUsecases.embeddings({
            model,
            input,
            encoding_format,
            dimensions,
        });
    }
    async getOrCreateNewThread(modelId, threadId) {
        if (threadId) {
            const thread = await this.threadUsecases.findOne(threadId);
            if (!thread)
                throw new Error(`Cannot find thread with id: ${threadId}`);
            return thread;
        }
        const model = await this.modelsUsecases.findOne(modelId);
        if (!model)
            throw new Error(`Cannot find model with id: ${modelId}`);
        const assistantDto = {
            avatar: '',
            id: 'jan',
            object: 'assistant',
            created_at: Date.now(),
            name: 'Jan',
            description: 'A default assistant that can use all downloaded models',
            model: modelId,
            instructions: '',
            tools: [],
            metadata: {},
        };
        const createThreadDto = {
            assistants: [assistantDto],
        };
        return this.threadUsecases.create(createThreadDto);
    }
};
exports.ChatCliUsecases = ChatCliUsecases;
exports.ChatCliUsecases = ChatCliUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [assistants_usecases_1.AssistantsUsecases,
        threads_usecases_1.ThreadsUsecases,
        chat_usecases_1.ChatUsecases,
        models_usecases_1.ModelsUsecases,
        messages_usecases_1.MessagesUsecases])
], ChatCliUsecases);
//# sourceMappingURL=chat.cli.usecases.js.map