"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitCliUsecases = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const axios_1 = require("@nestjs/axios");
const cli_progress_1 = require("cli-progress");
const decompress_1 = __importDefault(require("decompress"));
const node_process_1 = require("node:process");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const promises_1 = require("fs/promises");
const cortex_1 = require("../../constants/cortex");
const cuda_1 = require("../../../utils/cuda");
const engine_interface_1 = require("../types/engine.interface");
const cpu_instructions_1 = require("cpu-instructions");
let InitCliUsecases = class InitCliUsecases {
    constructor(httpService, fileManagerService) {
        this.httpService = httpService;
        this.fileManagerService = fileManagerService;
        this.defaultInstallationOptions = async () => {
            let options = {};
            if (process.platform === 'darwin') {
                return options;
            }
            options.runMode = (await (0, cuda_1.checkNvidiaGPUExist)()) ? 'GPU' : 'CPU';
            options.gpuType = 'Nvidia';
            options.instructions = await this.detectInstructions();
            return options;
        };
        this.installEngine = async (options, version = 'latest', engine = 'default', force = true) => {
            if (!options) {
                options = await this.defaultInstallationOptions();
            }
            const configs = await this.fileManagerService.getConfig();
            if (configs.initialized && !force)
                return;
            if (!(0, fs_1.existsSync)((0, path_1.join)(await this.fileManagerService.getCortexCppEnginePath(), engine_interface_1.Engines.llamaCPP)) ||
                (engine === engine_interface_1.Engines.llamaCPP && force))
                await this.installLlamaCppEngine(options, version);
            if (engine !== engine_interface_1.Engines.llamaCPP)
                await this.installAcceleratedEngine(version, engine);
            configs.initialized = true;
            await this.fileManagerService.writeConfigFile(configs);
        };
        this.installLlamaCppEngine = async (options, version = 'latest') => {
            const engineFileName = this.parseEngineFileName(options);
            const res = await (0, rxjs_1.firstValueFrom)(this.httpService.get(cortex_1.CORTEX_RELEASES_URL + `${version === 'latest' ? '/latest' : ''}`, {
                headers: {
                    'X-GitHub-Api-Version': '2022-11-28',
                    Accept: 'application/vnd.github+json',
                },
            }));
            if (!res.data) {
                console.log('Failed to fetch releases');
                (0, node_process_1.exit)(1);
            }
            let release = res.data;
            if (Array.isArray(res.data)) {
                release = Array(res.data)[0].find((e) => e.name === version.replace('v', ''));
            }
            const toDownloadAsset = release.assets.find((s) => s.name.includes(engineFileName));
            if (!toDownloadAsset) {
                console.log(`Could not find engine ${engineFileName}`);
                (0, node_process_1.exit)(1);
            }
            console.log(`Downloading default engine ${engineFileName}`);
            const dataFolderPath = await this.fileManagerService.getDataFolderPath();
            const engineDir = (0, path_1.join)(dataFolderPath, 'cortex-cpp');
            if ((0, fs_1.existsSync)(engineDir))
                (0, fs_1.rmSync)(engineDir, { recursive: true });
            const download = await (0, rxjs_1.firstValueFrom)(this.httpService.get(toDownloadAsset.browser_download_url, {
                responseType: 'stream',
            }));
            if (!download) {
                console.log('Failed to download model');
                process.exit(1);
            }
            const destination = (0, path_1.join)(dataFolderPath, toDownloadAsset.name);
            await new Promise((resolve, reject) => {
                const writer = (0, fs_1.createWriteStream)(destination);
                let receivedBytes = 0;
                const totalBytes = download.headers['content-length'];
                writer.on('finish', () => {
                    bar.stop();
                    resolve(true);
                });
                writer.on('error', (error) => {
                    bar.stop();
                    reject(error);
                });
                const bar = new cli_progress_1.SingleBar({}, cli_progress_1.Presets.shades_classic);
                bar.start(100, 0);
                download.data.on('data', (chunk) => {
                    receivedBytes += chunk.length;
                    bar.update(Math.floor((receivedBytes / totalBytes) * 100));
                });
                download.data.pipe(writer);
            });
            try {
                await (0, decompress_1.default)(destination, (0, path_1.join)(dataFolderPath));
            }
            catch (e) {
                console.error('Error decompressing file', e);
                (0, node_process_1.exit)(1);
            }
            await (0, promises_1.rm)(destination, { force: true });
            if (options.runMode === 'GPU' && !(await (0, cuda_1.cudaVersion)())) {
                await this.installCudaToolkitDependency(options.cudaVersion);
            }
        };
        this.parseEngineFileName = (options) => {
            const platform = process.platform === 'win32'
                ? 'windows'
                : process.platform === 'darwin'
                    ? 'mac'
                    : process.platform;
            const arch = process.arch === 'arm64' ? process.arch : 'amd64';
            const cudaVersion = (options === null || options === void 0 ? void 0 : options.runMode) === 'GPU'
                ? options.gpuType === 'Nvidia'
                    ? '-cuda-' + (options.cudaVersion === '11' ? '11-7' : '12-0')
                    : '-vulkan'
                : '';
            const instructions = (options === null || options === void 0 ? void 0 : options.instructions)
                ? `-${options.instructions}`
                : '';
            const engineName = `${platform}-${arch}${instructions.toLowerCase()}${cudaVersion}`;
            return `${engineName}.tar.gz`;
        };
        this.installCudaToolkitDependency = async (cudaVersion) => {
            const platform = process.platform === 'win32' ? 'windows' : 'linux';
            const dataFolderPath = await this.fileManagerService.getDataFolderPath();
            const url = cortex_1.CUDA_DOWNLOAD_URL.replace('<version>', cudaVersion === '11' ? '11.7' : '12.3').replace('<platform>', platform);
            const destination = (0, path_1.join)(dataFolderPath, 'cuda-toolkit.tar.gz');
            console.log('Downloading CUDA Toolkit dependency...');
            const download = await (0, rxjs_1.firstValueFrom)(this.httpService.get(url, {
                responseType: 'stream',
            }));
            if (!download) {
                console.log('Failed to download dependency');
                process.exit(1);
            }
            await new Promise((resolve, reject) => {
                const writer = (0, fs_1.createWriteStream)(destination);
                let receivedBytes = 0;
                const totalBytes = download.headers['content-length'];
                writer.on('finish', () => {
                    bar.stop();
                    resolve(true);
                });
                writer.on('error', (error) => {
                    bar.stop();
                    reject(error);
                });
                const bar = new cli_progress_1.SingleBar({}, cli_progress_1.Presets.shades_classic);
                bar.start(100, 0);
                download.data.on('data', (chunk) => {
                    receivedBytes += chunk.length;
                    bar.update(Math.floor((receivedBytes / totalBytes) * 100));
                });
                download.data.pipe(writer);
            });
            try {
                await (0, decompress_1.default)(destination, (0, path_1.join)(dataFolderPath, 'cortex-cpp'));
            }
            catch (e) {
                console.log(e);
                (0, node_process_1.exit)(1);
            }
            await (0, promises_1.rm)(destination, { force: true });
        };
        this.detectInstructions = () => {
            var _a;
            const cpuInstruction = (_a = cpu_instructions_1.cpuInfo.cpuInfo()[0]) !== null && _a !== void 0 ? _a : 'AVX';
            console.log(cpuInstruction, 'CPU instructions detected');
            return Promise.resolve(cpuInstruction);
        };
    }
    async installAcceleratedEngine(version = 'latest', engine = engine_interface_1.Engines.onnx) {
        const res = await (0, rxjs_1.firstValueFrom)(this.httpService.get((0, cortex_1.CORTEX_ENGINE_RELEASES_URL)(engine) +
            `${version === 'latest' ? '/latest' : ''}`, {
            headers: {
                'X-GitHub-Api-Version': '2022-11-28',
                Accept: 'application/vnd.github+json',
            },
        }));
        if (!(res === null || res === void 0 ? void 0 : res.data)) {
            console.log('Failed to fetch releases');
            (0, node_process_1.exit)(1);
        }
        let release = res === null || res === void 0 ? void 0 : res.data;
        if (Array.isArray(res === null || res === void 0 ? void 0 : res.data)) {
            release = Array(res === null || res === void 0 ? void 0 : res.data)[0].find((e) => e.name === version.replace('v', ''));
        }
        const toDownloadAsset = release.assets.find((s) => s.name.includes(process.platform === 'win32' ? 'windows' : 'linux'));
        if (!toDownloadAsset) {
            console.log(`Could not find engine file for platform ${process.platform}`);
            (0, node_process_1.exit)(1);
        }
        console.log(`Downloading engine file ${toDownloadAsset.name}`);
        const dataFolderPath = await this.fileManagerService.getDataFolderPath();
        const engineDir = (0, path_1.join)(dataFolderPath, 'cortex-cpp');
        const download = await (0, rxjs_1.firstValueFrom)(this.httpService.get(toDownloadAsset.browser_download_url, {
            responseType: 'stream',
        }));
        if (!download) {
            console.log('Failed to download model');
            process.exit(1);
        }
        const destination = (0, path_1.join)(dataFolderPath, toDownloadAsset.name);
        await new Promise((resolve, reject) => {
            const writer = (0, fs_1.createWriteStream)(destination);
            let receivedBytes = 0;
            const totalBytes = download.headers['content-length'];
            writer.on('finish', () => {
                bar.stop();
                resolve(true);
            });
            writer.on('error', (error) => {
                bar.stop();
                reject(error);
            });
            const bar = new cli_progress_1.SingleBar({}, cli_progress_1.Presets.shades_classic);
            bar.start(100, 0);
            download.data.on('data', (chunk) => {
                receivedBytes += chunk.length;
                bar.update(Math.floor((receivedBytes / totalBytes) * 100));
            });
            download.data.pipe(writer);
        });
        try {
            await (0, decompress_1.default)(destination, (0, path_1.join)(engineDir, 'engines'));
        }
        catch (e) {
            console.error('Error decompressing file', e);
            (0, node_process_1.exit)(1);
        }
        await (0, promises_1.rm)(destination, { force: true });
        for (const file of (0, fs_1.readdirSync)((0, path_1.join)(engineDir, 'engines', engine))) {
            if (file !== 'engine.dll') {
                await (0, fs_1.cpSync)((0, path_1.join)(engineDir, 'engines', engine, file), (0, path_1.join)(engineDir, file));
            }
        }
    }
};
exports.InitCliUsecases = InitCliUsecases;
exports.InitCliUsecases = InitCliUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], InitCliUsecases);
//# sourceMappingURL=init.cli.usecases.js.map