"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelsCliUsecases = void 0;
const node_process_1 = require("node:process");
const models_usecases_1 = require("../../../usecases/models/models.usecases");
const nest_commander_1 = require("nest-commander");
const common_1 = require("@nestjs/common");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const path_1 = require("path");
const js_yaml_1 = require("js-yaml");
const fs_1 = require("fs");
const normalize_model_id_1 = require("../../../utils/normalize-model-id");
const logs_1 = require("../../../utils/logs");
let ModelsCliUsecases = class ModelsCliUsecases {
    constructor(modelsUsecases, inquirerService, fileService) {
        this.modelsUsecases = modelsUsecases;
        this.inquirerService = inquirerService;
        this.fileService = fileService;
    }
    async startModel(modelId, preset) {
        const parsedPreset = await this.parsePreset(preset);
        return this.getModelOrStop(modelId)
            .then((model) => ({
            ...model,
            ...parsedPreset,
        }))
            .then((settings) => this.modelsUsecases.startModel(modelId, settings))
            .catch(async (e) => {
            console.error('Model start failed with reason:', e.message);
            (0, logs_1.printLastErrorLines)(await this.fileService.getLogPath());
            console.log('For more information, please check the logs at: %s', await this.fileService.getLogPath());
            process.exit(1);
        });
    }
    async stopModel(modelId) {
        return this.modelsUsecases.stopModel(modelId).then();
    }
    async updateModel(modelId, toUpdate) {
        return this.modelsUsecases.update(modelId, toUpdate);
    }
    async getModelOrStop(modelId) {
        const model = await this.modelsUsecases.findOne(modelId);
        if (!model) {
            console.debug('Model not found');
            (0, node_process_1.exit)(1);
        }
        return model;
    }
    async listAllModels() {
        return this.modelsUsecases.findAll();
    }
    async getModel(modelId) {
        return this.modelsUsecases.findOne(modelId);
    }
    async removeModel(modelId) {
        await this.getModelOrStop(modelId);
        return this.modelsUsecases.remove(modelId);
    }
    async pullModel(modelId) {
        const existingModel = await this.modelsUsecases.findOne(modelId);
        if ((0, normalize_model_id_1.isLocalModel)(existingModel === null || existingModel === void 0 ? void 0 : existingModel.files)) {
            console.error('Model already exists');
            process.exit(1);
        }
        console.log(`${modelId} not found on filesystem.\nDownloading from remote: https://huggingface.co/${modelId.includes('/') ? modelId : 'cortexso'} ...`);
        await this.modelsUsecases.pullModel(modelId, true, (files) => {
            return new Promise(async (resolve) => {
                var _a, _b;
                const listChoices = files
                    .filter((e) => e.quantization != null)
                    .map((e) => {
                    return {
                        name: e.quantization,
                        value: e.quantization,
                    };
                });
                if (listChoices.length > 1) {
                    const { quantization } = await this.inquirerService.inquirer.prompt({
                        type: 'list',
                        name: 'quantization',
                        message: 'Select quantization',
                        choices: listChoices,
                    });
                    resolve((_a = files
                        .filter((e) => !!e.quantization)
                        .find((e) => e.quantization === quantization)) !== null && _a !== void 0 ? _a : files[0]);
                }
                else {
                    resolve((_b = files.find((e) => e.rfilename.includes('.gguf'))) !== null && _b !== void 0 ? _b : files[0]);
                }
            });
        });
    }
    async parsePreset(preset) {
        const presetsFolder = await this.fileService.getPresetsPath();
        if (!(0, fs_1.existsSync)(presetsFolder))
            return {};
        const presetFile = (0, fs_1.readdirSync)(presetsFolder).find((file) => file.toLowerCase() === `${preset === null || preset === void 0 ? void 0 : preset.toLowerCase()}.yaml` ||
            file.toLowerCase() === `${preset === null || preset === void 0 ? void 0 : preset.toLocaleLowerCase()}.yml`);
        if (!presetFile)
            return {};
        const presetPath = (0, path_1.join)(presetsFolder, presetFile);
        if (!preset || !(0, fs_1.existsSync)(presetPath))
            return {};
        return preset
            ? (0, js_yaml_1.load)((0, fs_1.readFileSync)((0, path_1.join)(presetPath), 'utf-8'))
            : {};
    }
};
exports.ModelsCliUsecases = ModelsCliUsecases;
exports.ModelsCliUsecases = ModelsCliUsecases = __decorate([
    (0, common_1.Injectable)(),
    __param(1, (0, common_1.Inject)(nest_commander_1.InquirerService)),
    __metadata("design:paramtypes", [models_usecases_1.ModelsUsecases,
        nest_commander_1.InquirerService,
        file_manager_service_1.FileManagerService])
], ModelsCliUsecases);
//# sourceMappingURL=models.cli.usecases.js.map