"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PSCliUsecases = void 0;
const common_1 = require("@nestjs/common");
const ora_1 = __importDefault(require("ora"));
const cortex_1 = require("../../constants/cortex");
const axios_1 = require("@nestjs/axios");
const rxjs_1 = require("rxjs");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const engine_interface_1 = require("../types/engine.interface");
let PSCliUsecases = class PSCliUsecases {
    constructor(httpService, fileService) {
        this.httpService = httpService;
        this.fileService = fileService;
    }
    async getModels() {
        const configs = await this.fileService.getConfig();
        const runningSpinner = (0, ora_1.default)('Getting models...').start();
        return new Promise((resolve, reject) => (0, rxjs_1.firstValueFrom)(this.httpService.get((0, cortex_1.CORTEX_CPP_MODELS_URL)(configs.cortexCppHost, configs.cortexCppPort)))
            .then((res) => {
            const data = res.data;
            if (res.status === common_1.HttpStatus.OK &&
                data &&
                Array.isArray(data.data) &&
                data.data.length > 0) {
                runningSpinner.succeed();
                resolve(data.data.map((e) => {
                    var _a, _b, _c, _d;
                    const startTime = (_a = e.start_time) !== null && _a !== void 0 ? _a : new Date();
                    const currentTime = new Date();
                    const duration = currentTime.getTime() - new Date(startTime).getTime();
                    return {
                        modelId: e.id,
                        engine: (_b = e.engine) !== null && _b !== void 0 ? _b : engine_interface_1.Engines.llamaCPP,
                        status: 'running',
                        duration: this.formatDuration(duration),
                        ram: (_c = e.ram) !== null && _c !== void 0 ? _c : '-',
                        vram: (_d = e.vram) !== null && _d !== void 0 ? _d : '-',
                    };
                }));
            }
            else
                reject();
        })
            .catch(reject)).catch(() => {
            runningSpinner.succeed('');
            return [];
        });
    }
    async isAPIServerOnline(host = cortex_1.defaultCortexJsHost, port = cortex_1.defaultCortexJsPort) {
        return (0, rxjs_1.firstValueFrom)(this.httpService.get((0, cortex_1.CORTEX_JS_HEALTH_URL)(host, port)))
            .then((res) => res.status === common_1.HttpStatus.OK)
            .catch(() => false);
    }
    formatDuration(milliseconds) {
        const days = Math.floor(milliseconds / (1000 * 60 * 60 * 24));
        const hours = Math.floor((milliseconds % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
        const minutes = Math.floor((milliseconds % (1000 * 60 * 60)) / (1000 * 60));
        const seconds = Math.floor((milliseconds % (1000 * 60)) / 1000);
        let formattedDuration = '';
        if (days > 0) {
            formattedDuration += `${days}d `;
        }
        if (hours > 0) {
            formattedDuration += `${hours}h `;
        }
        if (minutes > 0) {
            formattedDuration += `${minutes}m `;
        }
        if (seconds > 0) {
            formattedDuration += `${seconds}s `;
        }
        return formattedDuration.trim();
    }
};
exports.PSCliUsecases = PSCliUsecases;
exports.PSCliUsecases = PSCliUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], PSCliUsecases);
//# sourceMappingURL=ps.cli.usecases.js.map