"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelsController = void 0;
const openapi = require("@nestjs/swagger");
const common_1 = require("@nestjs/common");
const models_usecases_1 = require("../../usecases/models/models.usecases");
const create_model_dto_1 = require("../dtos/models/create-model.dto");
const update_model_dto_1 = require("../dtos/models/update-model.dto");
const model_dto_1 = require("../dtos/models/model.dto");
const list_model_response_dto_1 = require("../dtos/models/list-model-response.dto");
const delete_model_dto_1 = require("../dtos/models/delete-model.dto");
const download_model_dto_1 = require("../dtos/models/download-model.dto");
const swagger_1 = require("@nestjs/swagger");
const start_model_success_dto_1 = require("../dtos/models/start-model-success.dto");
const transform_interceptor_1 = require("../interceptors/transform.interceptor");
const cortex_usecases_1 = require("../../usecases/cortex/cortex.usecases");
const model_settings_dto_1 = require("../dtos/models/model-settings.dto");
const telemetry_interface_1 = require("../../domain/telemetry/telemetry.interface");
const telemetry_usecases_1 = require("../../usecases/telemetry/telemetry.usecases");
const common_response_dto_1 = require("../dtos/common/common-response.dto");
let ModelsController = class ModelsController {
    constructor(modelsUsecases, cortexUsecases, telemetryUsecases) {
        this.modelsUsecases = modelsUsecases;
        this.cortexUsecases = cortexUsecases;
        this.telemetryUsecases = telemetryUsecases;
    }
    create(createModelDto) {
        return this.modelsUsecases.create(createModelDto);
    }
    startModel(modelId, params) {
        return this.cortexUsecases
            .startCortex()
            .then(() => this.modelsUsecases.startModel(modelId, params));
    }
    stopModel(modelId) {
        return this.modelsUsecases.stopModel(modelId);
    }
    downloadModel(modelId) {
        this.modelsUsecases.pullModel(modelId, false).then(() => this.telemetryUsecases.addEventToQueue({
            name: telemetry_interface_1.EventName.DOWNLOAD_MODEL,
            modelId,
        }));
        return {
            message: 'Download model started successfully.',
        };
    }
    abortDownloadModel(downloadId) {
        return this.modelsUsecases.abortDownloadModel(downloadId);
    }
    pullModel(modelId) {
        this.modelsUsecases.pullModel(modelId).then(() => this.telemetryUsecases.addEventToQueue({
            name: telemetry_interface_1.EventName.DOWNLOAD_MODEL,
            modelId,
        }));
        return {
            message: 'Download model started successfully.',
        };
    }
    findAll() {
        return this.modelsUsecases.findAll();
    }
    findOne(id) {
        return this.modelsUsecases.findOne(id);
    }
    async update(model, updateModelDto) {
        return this.modelsUsecases.update(model, updateModelDto);
    }
    remove(id) {
        return this.modelsUsecases.remove(id);
    }
};
exports.ModelsController = ModelsController;
__decorate([
    (0, common_1.HttpCode)(201),
    (0, swagger_1.ApiResponse)({
        status: 201,
        description: 'The model has been successfully created.',
        type: start_model_success_dto_1.StartModelSuccessDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Create model',
        description: 'Creates a model `.json` instance file manually.',
    }),
    (0, common_1.Post)(),
    openapi.ApiResponse({ status: 201 }),
    __param(0, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [create_model_dto_1.CreateModelDto]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "create", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'The model has been successfully started.',
        type: start_model_success_dto_1.StartModelSuccessDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Start model',
        description: 'Starts a model operation defined by a model `id`.',
    }),
    (0, swagger_1.ApiParam)({
        name: 'modelId',
        required: true,
        description: 'The unique identifier of the model.',
    }),
    (0, common_1.Post)(':modelId(*)/start'),
    openapi.ApiResponse({ status: 200, type: require("../dtos/models/start-model-success.dto").StartModelSuccessDto }),
    __param(0, (0, common_1.Param)('modelId')),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, model_settings_dto_1.ModelSettingsDto]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "startModel", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'The model has been successfully stopped.',
        type: start_model_success_dto_1.StartModelSuccessDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Stop model',
        description: 'Stops a model operation defined by a model `id`.',
    }),
    (0, swagger_1.ApiParam)({
        name: 'modelId',
        required: true,
        description: 'The unique identifier of the model.',
    }),
    (0, common_1.Post)(':modelId(*)/stop'),
    openapi.ApiResponse({ status: 200, type: require("../dtos/models/start-model-success.dto").StartModelSuccessDto }),
    __param(0, (0, common_1.Param)('modelId')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "stopModel", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'Ok',
        type: download_model_dto_1.DownloadModelResponseDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Download model',
        description: 'Downloads a specific model instance.',
        parameters: [
            {
                in: 'path',
                name: 'modelId',
                required: true,
                description: 'The unique identifier of the model.',
            },
        ],
    }),
    (0, common_1.Get)('download/:modelId(*)'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('modelId')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "downloadModel", null);
__decorate([
    (0, swagger_1.ApiOperation)({
        summary: 'Abort model download',
        description: 'Abort the model download operation.',
        parameters: [
            {
                in: 'path',
                name: 'download_id',
                required: true,
                description: 'The unique identifier of the download.',
            },
        ],
    }),
    (0, common_1.Get)('abort-download/:download_id(*)'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('download_id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "abortDownloadModel", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'Ok',
        type: common_response_dto_1.CommonResponseDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Download a remote model',
        description: 'Pulls a remote model template from cortex hub or huggingface and downloads it.',
    }),
    (0, swagger_1.ApiParam)({
        name: 'modelId',
        required: true,
        description: 'The unique identifier of the model.',
    }),
    (0, common_1.Get)('pull/:modelId(*)'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('modelId')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "pullModel", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'Ok',
        type: list_model_response_dto_1.ListModelsResponseDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'List models',
        description: "Lists the currently available models, and provides basic information about each one such as the owner and availability. [Equivalent to OpenAI's list model](https://platform.openai.com/docs/api-reference/models/list).",
    }),
    (0, common_1.Get)(),
    openapi.ApiResponse({ status: 200, type: [Object] }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "findAll", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'Ok',
        type: model_dto_1.ModelDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Get model',
        description: "Retrieves a model instance, providing basic information about the model such as the owner and permissions. [Equivalent to OpenAI's list model](https://platform.openai.com/docs/api-reference/models/retrieve).",
    }),
    (0, swagger_1.ApiParam)({
        name: 'id',
        required: true,
        description: 'The unique identifier of the model.',
    }),
    (0, common_1.Get)(':id(*)'),
    openapi.ApiResponse({ status: 200, type: Object }),
    __param(0, (0, common_1.Param)('id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "findOne", null);
__decorate([
    (0, common_1.HttpCode)(200),
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'The model has been successfully updated.',
        type: update_model_dto_1.UpdateModelDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Update model',
        description: "Updates a model instance defined by a model's `id`.",
        parameters: [
            {
                in: 'path',
                name: 'model',
                required: true,
                description: 'The unique identifier of the model.',
            },
        ],
    }),
    (0, common_1.Post)(':model(*)/config'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('model')),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, update_model_dto_1.UpdateModelDto]),
    __metadata("design:returntype", Promise)
], ModelsController.prototype, "update", null);
__decorate([
    (0, swagger_1.ApiResponse)({
        status: 200,
        description: 'The model has been successfully deleted.',
        type: delete_model_dto_1.DeleteModelResponseDto,
    }),
    (0, swagger_1.ApiOperation)({
        summary: 'Delete model',
        description: "Deletes a model. [Equivalent to OpenAI's delete model](https://platform.openai.com/docs/api-reference/models/delete).",
    }),
    (0, swagger_1.ApiParam)({
        name: 'id',
        required: true,
        description: 'The unique identifier of the model.',
    }),
    (0, common_1.Delete)(':id(*)'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], ModelsController.prototype, "remove", null);
exports.ModelsController = ModelsController = __decorate([
    (0, swagger_1.ApiTags)('Models'),
    (0, common_1.Controller)('models'),
    (0, common_1.UseInterceptors)(transform_interceptor_1.TransformInterceptor),
    __metadata("design:paramtypes", [models_usecases_1.ModelsUsecases,
        cortex_usecases_1.CortexUsecases,
        telemetry_usecases_1.TelemetryUsecases])
], ModelsController);
//# sourceMappingURL=models.controller.js.map