"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const oai_abstract_1 = require("../../../domain/abstracts/oai.abstract");
const path_1 = require("path");
const axios_1 = require("@nestjs/axios");
const cortex_1 = require("../../constants/cortex");
const node_fs_1 = require("node:fs");
const normalize_model_id_1 = require("../../../utils/normalize-model-id");
const rxjs_1 = require("rxjs");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
let CortexProvider = class CortexProvider extends oai_abstract_1.OAIEngineExtension {
    constructor(httpService, fileManagerService) {
        super(httpService);
        this.httpService = httpService;
        this.fileManagerService = fileManagerService;
        this.apiUrl = `http://${cortex_1.defaultCortexCppHost}:${cortex_1.defaultCortexCppPort}/inferences/server/chat_completion`;
        this.name = 'cortex';
        this.productName = 'Cortex Inference Engine';
        this.description = 'This extension enables chat completion API calls using the Cortex engine';
        this.version = '0.0.1';
        this.loadModelUrl = `http://${cortex_1.defaultCortexCppHost}:${cortex_1.defaultCortexCppPort}/inferences/server/loadmodel`;
        this.unloadModelUrl = `http://${cortex_1.defaultCortexCppHost}:${cortex_1.defaultCortexCppPort}/inferences/server/unloadmodel`;
        this.promptTemplateConverter = (promptTemplate) => {
            const systemMarker = '{system_message}';
            const promptMarker = '{prompt}';
            if (promptTemplate.includes(systemMarker) &&
                promptTemplate.includes(promptMarker)) {
                const systemIndex = promptTemplate.indexOf(systemMarker);
                const promptIndex = promptTemplate.indexOf(promptMarker);
                const system_prompt = promptTemplate.substring(0, systemIndex);
                const user_prompt = promptTemplate.substring(systemIndex + systemMarker.length, promptIndex);
                const ai_prompt = promptTemplate.substring(promptIndex + promptMarker.length);
                return { system_prompt, user_prompt, ai_prompt };
            }
            else if (promptTemplate.includes(promptMarker)) {
                const promptIndex = promptTemplate.indexOf(promptMarker);
                const user_prompt = promptTemplate.substring(0, promptIndex);
                const ai_prompt = promptTemplate.substring(promptIndex + promptMarker.length);
                return { user_prompt, ai_prompt };
            }
            return { error: 'Cannot split prompt template' };
        };
    }
    async loadModel(model, settings) {
        const modelsContainerDir = await this.fileManagerService.getModelsPath();
        let llama_model_path = settings === null || settings === void 0 ? void 0 : settings.llama_model_path;
        if (!llama_model_path) {
            const modelFolderFullPath = (0, path_1.join)(modelsContainerDir, (0, normalize_model_id_1.normalizeModelId)(model.model));
            const ggufFiles = (0, node_fs_1.readdirSync)(modelFolderFullPath).filter((file) => {
                return file.endsWith('.gguf');
            });
            if (ggufFiles.length === 0) {
                throw new Error('Model binary not found');
            }
            const modelBinaryLocalPath = (0, path_1.join)(modelFolderFullPath, ggufFiles[0]);
            llama_model_path = modelBinaryLocalPath;
        }
        const cpuThreadCount = 1;
        const modelSettings = {
            cpu_threads: cpuThreadCount,
            ...model,
            ...settings,
            llama_model_path,
            ...('mmproj' in model.files &&
                model.files.mmproj && {
                mmproj: settings === null || settings === void 0 ? void 0 : settings.mmproj,
            }),
        };
        if (model.prompt_template) {
            const promptTemplate = model.prompt_template;
            const prompt = this.promptTemplateConverter(promptTemplate);
            if (prompt === null || prompt === void 0 ? void 0 : prompt.error) {
                throw new Error(prompt.error);
            }
            modelSettings.system_prompt = prompt.system_prompt;
            modelSettings.user_prompt = prompt.user_prompt;
            modelSettings.ai_prompt = prompt.ai_prompt;
        }
        return (0, rxjs_1.firstValueFrom)(this.httpService.post(this.loadModelUrl, modelSettings)).then();
    }
    async unloadModel(modelId) {
        return (0, rxjs_1.firstValueFrom)(this.httpService.post(this.unloadModelUrl, { model: modelId })).then();
    }
};
CortexProvider = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], CortexProvider);
exports.default = CortexProvider;
//# sourceMappingURL=cortex.provider.js.map