"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtensionRepositoryImpl = void 0;
const common_1 = require("@nestjs/common");
const promises_1 = require("fs/promises");
const path_1 = require("path");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const fs_1 = require("fs");
const engine_interface_1 = require("../../commanders/types/engine.interface");
const cortex_provider_1 = __importDefault(require("../../providers/cortex/cortex.provider"));
const axios_1 = require("@nestjs/axios");
let ExtensionRepositoryImpl = class ExtensionRepositoryImpl {
    constructor(fileService, coreExtensions, httpService, fileManagerService) {
        this.fileService = fileService;
        this.coreExtensions = coreExtensions;
        this.httpService = httpService;
        this.fileManagerService = fileManagerService;
        this.extensions = new Map();
        this.loadCoreExtensions();
        this.loadExternalExtensions();
    }
    create(object) {
        var _a;
        this.extensions.set((_a = object.name) !== null && _a !== void 0 ? _a : '', object);
        return Promise.resolve(object);
    }
    findAll() {
        return Promise.resolve(Array.from(this.extensions.values()));
    }
    findOne(id) {
        var _a;
        return Promise.resolve((_a = this.extensions.get(id)) !== null && _a !== void 0 ? _a : null);
    }
    update() {
        throw new Error('Method not implemented.');
    }
    remove(id) {
        this.extensions.delete(id);
        return Promise.resolve();
    }
    async loadCoreExtensions() {
        const llamaCPPEngine = new cortex_provider_1.default(this.httpService, this.fileManagerService);
        llamaCPPEngine.name = engine_interface_1.Engines.llamaCPP;
        const onnxEngine = new cortex_provider_1.default(this.httpService, this.fileManagerService);
        onnxEngine.name = engine_interface_1.Engines.onnx;
        const tensorrtLLMEngine = new cortex_provider_1.default(this.httpService, this.fileManagerService);
        tensorrtLLMEngine.name = engine_interface_1.Engines.tensorrtLLM;
        await llamaCPPEngine.onLoad();
        await onnxEngine.onLoad();
        await tensorrtLLMEngine.onLoad();
        this.extensions.set(engine_interface_1.Engines.llamaCPP, llamaCPPEngine);
        this.extensions.set(engine_interface_1.Engines.onnx, onnxEngine);
        this.extensions.set(engine_interface_1.Engines.tensorrtLLM, tensorrtLLMEngine);
        for (const extension of this.coreExtensions) {
            await extension.onLoad();
            this.extensions.set(extension.name, extension);
        }
    }
    async loadExternalExtensions() {
        var _a;
        const extensionsPath = (_a = process.env.EXTENSIONS_PATH) !== null && _a !== void 0 ? _a : (await this.fileService.getExtensionsPath());
        this.loadExtensions(extensionsPath);
    }
    async loadExtensions(extensionsPath) {
        if (!(0, fs_1.existsSync)(extensionsPath))
            return;
        (0, promises_1.readdir)(extensionsPath).then((files) => {
            files.forEach(async (extension) => {
                const extensionFullPath = (0, path_1.join)(extensionsPath, extension);
                if (!(await (0, promises_1.lstat)(extensionFullPath)).isDirectory())
                    return;
                Promise.resolve(`${extensionFullPath}`).then(s => __importStar(require(s))).then((extensionClass) => {
                    const newExtension = new extensionClass.default();
                    this.extensions.set(extension, newExtension);
                });
            });
        });
    }
};
exports.ExtensionRepositoryImpl = ExtensionRepositoryImpl;
exports.ExtensionRepositoryImpl = ExtensionRepositoryImpl = __decorate([
    (0, common_1.Injectable)(),
    __param(1, (0, common_1.Inject)('EXTENSIONS_PROVIDER')),
    __metadata("design:paramtypes", [file_manager_service_1.FileManagerService, Array, axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], ExtensionRepositoryImpl);
//# sourceMappingURL=extension.repository.js.map