"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelRepositoryImpl = void 0;
const common_1 = require("@nestjs/common");
const path_1 = require("path");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
const fs_1 = require("fs");
const js_yaml_1 = require("js-yaml");
const normalize_model_id_1 = require("../../../utils/normalize-model-id");
let ModelRepositoryImpl = class ModelRepositoryImpl {
    constructor(fileService) {
        this.fileService = fileService;
        this.models = new Map([]);
        this.fileModel = new Map([]);
        this.loaded = false;
        this.loadModels();
    }
    async create(object) {
        var _a, _b;
        const modelsFolderPath = (0, path_1.join)(await this.fileService.getDataFolderPath(), 'models');
        const modelYaml = (0, js_yaml_1.dump)(object);
        if (!(0, fs_1.existsSync)(modelsFolderPath))
            (0, fs_1.mkdirSync)(modelsFolderPath);
        const modelsPath = (_a = process.env.EXTENSIONS_PATH) !== null && _a !== void 0 ? _a : (await this.fileService.getModelsPath());
        (0, fs_1.writeFileSync)((0, path_1.join)(modelsPath, `${(0, normalize_model_id_1.normalizeModelId)(object.model)}.yaml`), modelYaml);
        this.models.set((_b = object.model) !== null && _b !== void 0 ? _b : '', object);
        return Promise.resolve(object);
    }
    findAll() {
        return this.loadModels().then((res) => res.filter((model) => (0, normalize_model_id_1.isLocalModel)(model.files)));
    }
    findOne(id) {
        return this.loadModels().then(() => { var _a; return (_a = this.models.get(id)) !== null && _a !== void 0 ? _a : null; });
    }
    async update(id, object) {
        var _a, _b;
        const originalModel = await this.findOne(id);
        if (!originalModel)
            throw new Error('Model not found');
        const updatedModel = {
            ...originalModel,
            ...object,
        };
        const modelYaml = (0, js_yaml_1.dump)(updatedModel);
        const modelsPath = (_a = process.env.EXTENSIONS_PATH) !== null && _a !== void 0 ? _a : (await this.fileService.getModelsPath());
        (0, fs_1.writeFileSync)((0, path_1.join)(modelsPath, (_b = this.fileModel.get(id)) !== null && _b !== void 0 ? _b : `${(0, normalize_model_id_1.normalizeModelId)(id)}.yaml`), modelYaml);
        this.models.set(id !== null && id !== void 0 ? id : '', updatedModel);
    }
    async remove(id) {
        var _a;
        this.models.delete(id);
        const yamlFilePath = (0, path_1.join)(await this.fileService.getModelsPath(), (_a = this.fileModel.get(id)) !== null && _a !== void 0 ? _a : id);
        if ((0, fs_1.existsSync)(yamlFilePath))
            (0, fs_1.rmSync)(yamlFilePath);
        return Promise.resolve();
    }
    async loadModels() {
        var _a;
        if (this.loaded)
            return Array.from(this.models.values());
        const modelsPath = (_a = process.env.EXTENSIONS_PATH) !== null && _a !== void 0 ? _a : (await this.fileService.getModelsPath());
        if (!(0, fs_1.existsSync)(modelsPath))
            return [];
        const modelFiles = (0, fs_1.readdirSync)(modelsPath)
            .filter((file) => (0, path_1.extname)(file).toLowerCase() === '.yaml' ||
            (0, path_1.extname)(file).toLowerCase() === '.yml')
            .map((file) => (0, path_1.join)(modelsPath, file));
        modelFiles.forEach(async (modelFile) => {
            const model = (0, fs_1.readFileSync)(modelFile, 'utf8');
            const yamlObject = (0, js_yaml_1.load)(model);
            const fileName = (0, path_1.basename)(modelFile);
            if (yamlObject) {
                this.fileModel.set(yamlObject.model, fileName);
                this.models.set(yamlObject.model, yamlObject);
            }
        });
        this.loaded = true;
        return Array.from(this.models.values());
    }
};
exports.ModelRepositoryImpl = ModelRepositoryImpl;
exports.ModelRepositoryImpl = ModelRepositoryImpl = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [file_manager_service_1.FileManagerService])
], ModelRepositoryImpl);
//# sourceMappingURL=model.repository.js.map