import { TelemetryRepository } from '@/domain/repositories/telemetry.interface';
import { CrashReportAttributes, TelemetrySource, Telemetry, EventAttributes, TelemetryAnonymized, BenchmarkHardware } from '@/domain/telemetry/telemetry.interface';
import { FileManagerService } from '@/infrastructure/services/file-manager/file-manager.service';
import { ModelStat } from '@/infrastructure/commanders/types/model-stat.interface';
export declare class TelemetryRepositoryImpl implements TelemetryRepository {
    private readonly fileManagerService;
    private readonly telemetryResource;
    private readonly crashReportFileName;
    private readonly anonymizedDataFileName;
    constructor(fileManagerService: FileManagerService);
    private getTelemetryDirectory;
    private generateChecksum;
    sendTelemetryToServer(telemetryEvent: Telemetry['event'], type?: 'crash-report' | 'metrics'): Promise<void>;
    sendBenchmarkToServer(data: {
        hardware: BenchmarkHardware;
        results: any;
        metrics: any;
        model: ModelStat;
        sessionId: string;
    }): Promise<void>;
    sendTelemetryToOTelCollector(endpoint: string, telemetry: Telemetry): Promise<void>;
    markLastCrashReportAsSent(): Promise<void>;
    readCrashReports(callback: (Telemetry: Telemetry) => void): Promise<void>;
    getLastCrashReport(): Promise<Telemetry | null>;
    createCrashReport(crashReport: CrashReportAttributes, source: TelemetrySource): Promise<void>;
    private convertToTelemetryEvent;
    sendEvent(events: EventAttributes[], source: TelemetrySource): Promise<void>;
    getAnonymizedData(): Promise<TelemetryAnonymized | null>;
    updateAnonymousData(data: TelemetryAnonymized): Promise<void>;
}
