"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TelemetryRepositoryImpl = void 0;
const cypto = __importStar(require("crypto"));
const os_1 = __importDefault(require("os"));
const systeminformation_1 = __importDefault(require("systeminformation"));
const common_1 = require("@nestjs/common");
const path_1 = require("path");
const package_json_1 = __importDefault(require("../../../../package.json"));
const axios_1 = __importDefault(require("axios"));
const cortex_1 = require("../../constants/cortex");
const file_manager_service_1 = require("../../services/file-manager/file-manager.service");
let TelemetryRepositoryImpl = class TelemetryRepositoryImpl {
    constructor(fileManagerService) {
        this.fileManagerService = fileManagerService;
        this.telemetryResource = {
            osName: process.platform,
            osVersion: process.version,
            architecture: process.arch,
            appVersion: package_json_1.default.version,
        };
        this.crashReportFileName = 'crash-report.jsonl';
        this.anonymizedDataFileName = 'session.json';
    }
    async getTelemetryDirectory() {
        const dataFolderPath = await this.fileManagerService.getDataFolderPath();
        await this.fileManagerService.createFolderIfNotExistInDataFolder('telemetry');
        return (0, path_1.join)(dataFolderPath, 'telemetry');
    }
    generateChecksum(data) {
        const hash = cypto.createHash('sha256');
        hash.update(JSON.stringify(data));
        return hash.digest('hex');
    }
    async sendTelemetryToServer(telemetryEvent, type = 'crash-report') {
        try {
            await axios_1.default.post(`${cortex_1.telemetryServerUrl}/api/v1/${type}`, telemetryEvent, {
                headers: {
                    'Content-Type': 'application/json',
                    'cortex-checksum': this.generateChecksum(telemetryEvent),
                    timeout: 1000,
                },
            });
        }
        catch (error) { }
    }
    async sendBenchmarkToServer(data) {
        try {
            await axios_1.default.post(`${cortex_1.telemetryServerUrl}/api/v1/benchmark`, data, {
                headers: {
                    'Content-Type': 'application/json',
                    'cortex-checksum': this.generateChecksum(data),
                },
            });
        }
        catch (error) { }
    }
    async sendTelemetryToOTelCollector(endpoint, telemetry) {
        try {
            console.log('Sending telemetry to OTel collector');
            await axios_1.default.post(`${endpoint}/v1/logs`, telemetry.event, {
                headers: {
                    'Content-Type': 'application/json',
                },
            });
        }
        catch (error) { }
    }
    async markLastCrashReportAsSent() {
        try {
            const { data, position } = await this.fileManagerService.getLastLine((0, path_1.join)(await this.getTelemetryDirectory(), this.crashReportFileName));
            const Telemetry = JSON.parse(data);
            Telemetry.metadata.sentAt = new Date().toISOString();
            await this.fileManagerService.modifyLine((0, path_1.join)(await this.getTelemetryDirectory(), this.crashReportFileName), JSON.stringify(Telemetry), position);
        }
        catch (error) { }
    }
    async readCrashReports(callback) {
        this.fileManagerService.readLines((0, path_1.join)(await this.getTelemetryDirectory(), this.crashReportFileName), (line) => {
            const data = JSON.parse(line);
            callback(data);
        });
    }
    async getLastCrashReport() {
        try {
            await this.fileManagerService.createFolderIfNotExistInDataFolder('telemetry');
            const { data } = await this.fileManagerService.getLastLine((0, path_1.join)(await this.getTelemetryDirectory(), this.crashReportFileName));
            if (!data) {
                return null;
            }
            return JSON.parse(data);
        }
        catch (error) {
            return null;
        }
    }
    async createCrashReport(crashReport, source) {
        const telemetryEvent = await this.convertToTelemetryEvent({
            attributes: crashReport,
            source,
            type: 'crash-report',
        });
        const metadata = {
            createdAt: new Date().toISOString(),
            sentAt: null,
        };
        return this.fileManagerService.append((0, path_1.join)(await this.getTelemetryDirectory(), this.crashReportFileName), JSON.stringify({
            metadata,
            event: {
                resourceLogs: [telemetryEvent],
            },
        }));
    }
    async convertToTelemetryEvent({ attributes, source, type, }) {
        const gpus = (await systeminformation_1.default.graphics()).controllers.map(({ model, vendor, vram, vramDynamic }) => ({
            model,
            vendor,
            vram,
            vramDynamic,
        }));
        const body = type === 'crash-report'
            ? attributes.message
            : attributes.name;
        const severity = type === 'crash-report' ? 'ERROR' : 'INFO';
        const resourceAttributes = Object.entries({
            ...this.telemetryResource,
            'service.name': type,
            cpu: os_1.default.cpus()[0].model,
            gpus: JSON.stringify(gpus),
            source,
        }).map(([key, value]) => ({
            key,
            value: { stringValue: value },
        }));
        const telemetryLogAttributes = Object.entries(attributes).map(([key, value]) => {
            if (typeof value === 'object') {
                return {
                    key,
                    value: {
                        kvlist_value: {
                            values: Object.entries(value).map(([k, v]) => ({
                                key: k,
                                value: { stringValue: v },
                            })),
                        },
                    },
                };
            }
            return {
                key,
                value: { stringValue: value },
            };
        });
        return {
            resource: {
                attributes: resourceAttributes,
            },
            scopeLogs: [
                {
                    scope: {},
                    logRecords: [
                        {
                            traceId: cypto.randomBytes(16).toString('hex'),
                            startTimeUnixNano: (BigInt(Date.now()) * BigInt(1000000)).toString(),
                            body: { stringValue: body },
                            severityText: severity,
                            attributes: telemetryLogAttributes,
                        },
                    ],
                },
            ],
        };
    }
    async sendEvent(events, source) {
        const telemetryEvents = await Promise.all(events.map(async (event) => this.convertToTelemetryEvent({
            attributes: event,
            source,
            type: 'metrics',
        })));
        await this.sendTelemetryToServer({
            resourceLogs: telemetryEvents,
        }, 'metrics');
    }
    async getAnonymizedData() {
        const content = await this.fileManagerService.readFile((0, path_1.join)(await this.getTelemetryDirectory(), this.anonymizedDataFileName));
        if (!content) {
            return null;
        }
        const data = JSON.parse(content);
        return data;
    }
    async updateAnonymousData(data) {
        return this.fileManagerService.writeFile((0, path_1.join)(await this.getTelemetryDirectory(), this.anonymizedDataFileName), JSON.stringify(data));
    }
};
exports.TelemetryRepositoryImpl = TelemetryRepositoryImpl;
exports.TelemetryRepositoryImpl = TelemetryRepositoryImpl = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [file_manager_service_1.FileManagerService])
], TelemetryRepositoryImpl);
//# sourceMappingURL=telemetry.repository.js.map