"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DownloadManagerService = void 0;
const download_interface_1 = require("../../../domain/models/download.interface");
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const event_emitter_1 = require("@nestjs/event-emitter");
const cli_progress_1 = require("cli-progress");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
const rxjs_1 = require("rxjs");
let DownloadManagerService = class DownloadManagerService {
    constructor(httpService, eventEmitter) {
        this.httpService = httpService;
        this.eventEmitter = eventEmitter;
        this.allDownloadStates = [];
        this.abortControllers = {};
    }
    async abortDownload(downloadId) {
        if (!this.abortControllers[downloadId]) {
            return;
        }
        Object.keys(this.abortControllers[downloadId]).forEach((destination) => {
            this.abortControllers[downloadId][destination].abort();
        });
        delete this.abortControllers[downloadId];
        this.allDownloadStates = this.allDownloadStates.filter((downloadState) => downloadState.id !== downloadId);
        this.eventEmitter.emit('download.event.aborted', this.allDownloadStates);
    }
    async submitDownloadRequest(downloadId, title, downloadType, urlToDestination, finishedCallback, inSequence = true) {
        if (this.allDownloadStates.find((downloadState) => downloadState.id === downloadId)) {
            return;
        }
        const downloadItems = Object.keys(urlToDestination).map((url) => {
            const destination = urlToDestination[url];
            const downloadItem = {
                id: destination,
                time: {
                    elapsed: 0,
                    remaining: 0,
                },
                size: {
                    total: 0,
                    transferred: 0,
                },
                status: download_interface_1.DownloadStatus.Downloading,
            };
            return downloadItem;
        });
        const downloadState = {
            id: downloadId,
            title: title,
            type: downloadType,
            status: download_interface_1.DownloadStatus.Downloading,
            children: downloadItems,
        };
        this.allDownloadStates.push(downloadState);
        this.abortControllers[downloadId] = {};
        const callBack = async () => {
            await (finishedCallback === null || finishedCallback === void 0 ? void 0 : finishedCallback());
            delete this.abortControllers[downloadId];
            const currentDownloadState = this.allDownloadStates.find((downloadState) => downloadState.id === downloadId);
            if (currentDownloadState) {
                currentDownloadState.status = download_interface_1.DownloadStatus.Downloaded;
                this.allDownloadStates = this.allDownloadStates.filter((downloadState) => downloadState.id !== downloadId);
            }
            this.eventEmitter.emit('download.event', this.allDownloadStates);
        };
        if (!inSequence) {
            return Promise.all(Object.keys(urlToDestination).map((url) => {
                const destination = urlToDestination[url];
                return this.downloadFile(downloadId, url, destination);
            })).then(callBack);
        }
        else {
            for (const url of Object.keys(urlToDestination)) {
                const destination = urlToDestination[url];
                await this.downloadFile(downloadId, url, destination);
            }
            return callBack();
        }
    }
    async downloadFile(downloadId, url, destination) {
        const controller = new AbortController();
        this.abortControllers[downloadId][destination] = controller;
        return new Promise(async (resolve, reject) => {
            const response = await (0, rxjs_1.firstValueFrom)(this.httpService.get(url, {
                responseType: 'stream',
                signal: controller.signal,
            }));
            if (!response) {
                throw new Error('Failed to download model');
            }
            const writer = (0, node_fs_1.createWriteStream)(destination);
            const totalBytes = Number(response.headers['content-length']);
            const currentDownloadState = this.allDownloadStates.find((downloadState) => downloadState.id === downloadId);
            if (!currentDownloadState) {
                resolve();
                return;
            }
            const downloadItem = currentDownloadState === null || currentDownloadState === void 0 ? void 0 : currentDownloadState.children.find((downloadItem) => downloadItem.id === destination);
            if (downloadItem) {
                downloadItem.size.total = totalBytes;
            }
            console.log('Downloading', (0, node_path_1.basename)(destination));
            let transferredBytes = 0;
            const bar = new cli_progress_1.SingleBar({}, cli_progress_1.Presets.shades_classic);
            bar.start(100, 0);
            writer.on('finish', () => {
                try {
                    delete this.abortControllers[downloadId][destination];
                    const currentDownloadState = this.allDownloadStates.find((downloadState) => downloadState.id === downloadId);
                    if (!currentDownloadState)
                        return;
                    const downloadItem = currentDownloadState === null || currentDownloadState === void 0 ? void 0 : currentDownloadState.children.find((downloadItem) => downloadItem.id === destination);
                    if (downloadItem) {
                        downloadItem.status = download_interface_1.DownloadStatus.Downloaded;
                    }
                    this.eventEmitter.emit('download.event', this.allDownloadStates);
                }
                finally {
                    bar.stop();
                    resolve();
                }
            });
            writer.on('error', (error) => {
                try {
                    delete this.abortControllers[downloadId][destination];
                    const currentDownloadState = this.allDownloadStates.find((downloadState) => downloadState.id === downloadId);
                    if (!currentDownloadState)
                        return;
                    const downloadItem = currentDownloadState === null || currentDownloadState === void 0 ? void 0 : currentDownloadState.children.find((downloadItem) => downloadItem.id === destination);
                    if (downloadItem) {
                        downloadItem.status = download_interface_1.DownloadStatus.Error;
                        downloadItem.error = error.message;
                    }
                    currentDownloadState.status = download_interface_1.DownloadStatus.Error;
                    currentDownloadState.error = error.message;
                    this.allDownloadStates = this.allDownloadStates.filter((downloadState) => downloadState.id !== downloadId);
                    this.eventEmitter.emit('download.event', this.allDownloadStates);
                }
                finally {
                    bar.stop();
                    resolve();
                }
            });
            response.data.on('data', (chunk) => {
                transferredBytes += chunk.length;
                const currentDownloadState = this.allDownloadStates.find((downloadState) => downloadState.id === downloadId);
                if (!currentDownloadState)
                    return;
                const downloadItem = currentDownloadState === null || currentDownloadState === void 0 ? void 0 : currentDownloadState.children.find((downloadItem) => downloadItem.id === destination);
                if (downloadItem) {
                    downloadItem.size.transferred = transferredBytes;
                    bar.update(Math.floor((transferredBytes / totalBytes) * 100));
                }
                this.eventEmitter.emit('download.event', this.allDownloadStates);
            });
            response.data.pipe(writer);
        });
    }
    getDownloadStates() {
        return this.allDownloadStates;
    }
};
exports.DownloadManagerService = DownloadManagerService;
exports.DownloadManagerService = DownloadManagerService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService,
        event_emitter_1.EventEmitter2])
], DownloadManagerService);
//# sourceMappingURL=download-manager.service.js.map