"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileManagerService = void 0;
const common_1 = require("@nestjs/common");
const os_1 = __importDefault(require("os"));
const node_path_1 = require("node:path");
const node_fs_1 = require("node:fs");
const util_1 = require("util");
const js_yaml_1 = __importDefault(require("js-yaml"));
const fs_1 = require("fs");
const readline_1 = require("readline");
const cortex_1 = require("../../constants/cortex");
const readFileAsync = (0, util_1.promisify)(node_fs_1.read);
const openAsync = (0, util_1.promisify)(node_fs_1.open);
const closeAsync = (0, util_1.promisify)(node_fs_1.close);
const writeAsync = (0, util_1.promisify)(fs_1.write);
let FileManagerService = class FileManagerService {
    constructor() {
        this.configFile = '.cortexrc';
        this.cortexDirectoryName = 'cortex';
        this.modelFolderName = 'models';
        this.presetFolderName = 'presets';
        this.extensionFoldername = 'extensions';
        this.benchmarkFoldername = 'benchmark';
        this.cortexCppFolderName = 'cortex-cpp';
        this.cortexTelemetryFolderName = 'telemetry';
    }
    async getConfig() {
        const homeDir = os_1.default.homedir();
        const configPath = (0, node_path_1.join)(homeDir, this.configFile);
        if (!(0, node_fs_1.existsSync)(configPath)) {
            const config = this.defaultConfig();
            await this.createFolderIfNotExist(config.dataFolderPath);
            await this.writeConfigFile(config);
            return config;
        }
        try {
            const content = await node_fs_1.promises.readFile(configPath, 'utf8');
            const config = js_yaml_1.default.load(content);
            return {
                ...this.defaultConfig(),
                ...config,
            };
        }
        catch (error) {
            console.warn('Error reading config file. Using default config.');
            console.warn(error);
            const config = this.defaultConfig();
            await this.createFolderIfNotExist(config.dataFolderPath);
            await this.writeConfigFile(config);
            return config;
        }
    }
    async writeConfigFile(config) {
        const homeDir = os_1.default.homedir();
        const configPath = (0, node_path_1.join)(homeDir, this.configFile);
        const configString = js_yaml_1.default.dump(config);
        await node_fs_1.promises.writeFile(configPath, configString, 'utf8');
    }
    async createFolderIfNotExist(dataFolderPath) {
        if (!(0, node_fs_1.existsSync)(dataFolderPath)) {
            await node_fs_1.promises.mkdir(dataFolderPath, { recursive: true });
        }
        const modelFolderPath = (0, node_path_1.join)(dataFolderPath, this.modelFolderName);
        const cortexCppFolderPath = (0, node_path_1.join)(dataFolderPath, this.cortexCppFolderName);
        const cortexTelemetryFolderPath = (0, node_path_1.join)(dataFolderPath, this.cortexTelemetryFolderName);
        if (!(0, node_fs_1.existsSync)(modelFolderPath)) {
            await node_fs_1.promises.mkdir(modelFolderPath, { recursive: true });
        }
        if (!(0, node_fs_1.existsSync)(cortexCppFolderPath)) {
            await node_fs_1.promises.mkdir(cortexCppFolderPath, { recursive: true });
        }
        if (!(0, node_fs_1.existsSync)(cortexTelemetryFolderPath)) {
            await node_fs_1.promises.mkdir(cortexTelemetryFolderPath, { recursive: true });
        }
    }
    defaultConfig() {
        const homeDir = os_1.default.homedir();
        const dataFolderPath = (0, node_path_1.join)(homeDir, this.cortexDirectoryName);
        return {
            dataFolderPath,
            initialized: false,
            cortexCppHost: cortex_1.defaultCortexCppHost,
            cortexCppPort: cortex_1.defaultCortexCppPort,
        };
    }
    async getDataFolderPath() {
        const config = await this.getConfig();
        return config.dataFolderPath;
    }
    async getLastLine(filePath) {
        try {
            const fileDescriptor = await openAsync(filePath, 'a+');
            const stats = await node_fs_1.promises.stat(filePath);
            const bufferSize = 1024 * 5;
            const buffer = Buffer.alloc(bufferSize);
            const filePosition = stats.size;
            let lastPosition = filePosition;
            let data = '';
            let newLineIndex = -1;
            async function readPreviousChunk() {
                const readPosition = Math.max(0, lastPosition - bufferSize);
                const chunkSize = Math.min(bufferSize, lastPosition);
                const { bytesRead } = await readFileAsync(fileDescriptor, buffer, 0, chunkSize, readPosition);
                data = buffer.slice(0, bytesRead).toString() + data;
                lastPosition -= bufferSize;
                newLineIndex = data.lastIndexOf('\n');
                if (newLineIndex === -1 && lastPosition > 0) {
                    return readPreviousChunk();
                }
                else {
                    const lastLine = data.slice(newLineIndex + 1).trim();
                    await closeAsync(fileDescriptor);
                    return {
                        data: lastLine,
                        position: readPosition + newLineIndex + 1,
                    };
                }
            }
            return await readPreviousChunk();
        }
        catch (err) {
            throw err;
        }
    }
    async modifyLine(filePath, modifiedLine, position) {
        try {
            const fd = await openAsync(filePath, 'r+');
            const buffer = Buffer.from(modifiedLine, 'utf8');
            await writeAsync(fd, buffer, 0, buffer.length, position);
            await closeAsync(fd);
        }
        catch (err) {
            throw err;
        }
    }
    async append(filePath, data) {
        try {
            const stats = await node_fs_1.promises.stat(filePath);
            return await node_fs_1.promises.appendFile(filePath, stats.size === 0 ? data : `\n${data}`, {
                encoding: 'utf8',
                flag: 'a+',
            });
        }
        catch (err) {
            throw err;
        }
    }
    readLines(filePath, callback) {
        const fileStream = (0, node_fs_1.createReadStream)(filePath);
        const rl = (0, readline_1.createInterface)({
            input: fileStream,
            crlfDelay: Infinity,
        });
        rl.on('line', callback);
    }
    async getModelsPath() {
        const dataFolderPath = await this.getDataFolderPath();
        return (0, node_path_1.join)(dataFolderPath, this.modelFolderName);
    }
    async getPresetsPath() {
        const dataFolderPath = await this.getDataFolderPath();
        return (0, node_path_1.join)(dataFolderPath, this.presetFolderName);
    }
    async getExtensionsPath() {
        const dataFolderPath = await this.getDataFolderPath();
        return (0, node_path_1.join)(dataFolderPath, this.extensionFoldername);
    }
    async getBenchmarkPath() {
        const dataFolderPath = await this.getDataFolderPath();
        return (0, node_path_1.join)(dataFolderPath, this.benchmarkFoldername);
    }
    async getCortexCppEnginePath() {
        return (0, node_path_1.join)(await this.getDataFolderPath(), 'cortex-cpp', 'engines');
    }
    async getLogPath() {
        return (0, node_path_1.join)(await this.getDataFolderPath(), 'cortex.log');
    }
    async createFolderIfNotExistInDataFolder(folderName) {
        const dataFolderPath = await this.getDataFolderPath();
        const folderPath = (0, node_path_1.join)(dataFolderPath, folderName);
        if (!(0, node_fs_1.existsSync)(folderPath)) {
            await node_fs_1.promises.mkdir(folderPath, { recursive: true });
        }
    }
    async readFile(filePath) {
        try {
            const isFileExist = (0, node_fs_1.existsSync)(filePath);
            if (!isFileExist) {
                return null;
            }
            const content = await node_fs_1.promises.readFile(filePath, {
                encoding: 'utf8',
            });
            return content;
        }
        catch (error) {
            throw error;
        }
    }
    async writeFile(filePath, data) {
        try {
            const dirPath = filePath.split('/').slice(0, -1).join('/');
            await this.createFolderIfNotExistInDataFolder(dirPath);
            return node_fs_1.promises.writeFile(filePath, data, {
                encoding: 'utf8',
                flag: 'w+',
            });
        }
        catch (error) {
            throw error;
        }
    }
};
exports.FileManagerService = FileManagerService;
exports.FileManagerService = FileManagerService = __decorate([
    (0, common_1.Injectable)()
], FileManagerService);
//# sourceMappingURL=file-manager.service.js.map