"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssistantsUsecases = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("typeorm");
const page_dto_1 = require("../../infrastructure/dtos/page.dto");
const model_interface_1 = require("../../domain/repositories/model.interface");
const model_not_found_exception_1 = require("../../infrastructure/exception/model-not-found.exception");
const duplicate_assistant_exception_1 = require("../../infrastructure/exception/duplicate-assistant.exception");
let AssistantsUsecases = class AssistantsUsecases {
    constructor(assistantRepository, modelRepository) {
        this.assistantRepository = assistantRepository;
        this.modelRepository = modelRepository;
    }
    async create(createAssistantDto) {
        const { top_p, temperature, model, id } = createAssistantDto;
        if (model !== '*') {
            const modelEntity = await this.modelRepository.findOne(model);
            if (!modelEntity) {
                throw new model_not_found_exception_1.ModelNotFoundException(model);
            }
        }
        const assistant = {
            ...createAssistantDto,
            object: 'assistant',
            created_at: Date.now(),
            response_format: null,
            tool_resources: null,
            top_p: top_p !== null && top_p !== void 0 ? top_p : null,
            temperature: temperature !== null && temperature !== void 0 ? temperature : null,
        };
        try {
            await this.assistantRepository.insert(assistant);
        }
        catch (err) {
            if (err instanceof typeorm_1.QueryFailedError) {
                if (err.driverError.code === 'SQLITE_CONSTRAINT')
                    throw new duplicate_assistant_exception_1.DuplicateAssistantException(id);
            }
            throw err;
        }
        return this.findOne(assistant.id);
    }
    async listAssistants(limit, order, after, before) {
        var _a, _b, _c, _d;
        const queryBuilder = this.assistantRepository.createQueryBuilder();
        const normalizedOrder = order === 'asc' ? 'ASC' : 'DESC';
        queryBuilder.orderBy('created_at', normalizedOrder).take(limit + 1);
        if (after) {
            queryBuilder.andWhere('id > :after', { after });
        }
        if (before) {
            queryBuilder.andWhere('id < :before', { before });
        }
        const { entities: assistants } = await queryBuilder.getRawAndEntities();
        let hasMore = false;
        if (assistants.length > limit) {
            hasMore = true;
            assistants.pop();
        }
        const firstId = (_b = (_a = assistants[0]) === null || _a === void 0 ? void 0 : _a.id) !== null && _b !== void 0 ? _b : undefined;
        const lastId = (_d = (_c = assistants[assistants.length - 1]) === null || _c === void 0 ? void 0 : _c.id) !== null && _d !== void 0 ? _d : undefined;
        return new page_dto_1.PageDto(assistants, hasMore, firstId, lastId);
    }
    async findAll() {
        return this.assistantRepository.find();
    }
    async findOne(id) {
        return this.assistantRepository.findOne({
            where: { id },
        });
    }
    async remove(id) {
        return this.assistantRepository.delete(id);
    }
};
exports.AssistantsUsecases = AssistantsUsecases;
exports.AssistantsUsecases = AssistantsUsecases = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)('ASSISTANT_REPOSITORY')),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        model_interface_1.ModelRepository])
], AssistantsUsecases);
//# sourceMappingURL=assistants.usecases.js.map