"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatUsecases = void 0;
const common_1 = require("@nestjs/common");
const model_not_found_exception_1 = require("../../infrastructure/exception/model-not-found.exception");
const telemetry_usecases_1 = require("../telemetry/telemetry.usecases");
const telemetry_interface_1 = require("../../domain/telemetry/telemetry.interface");
const model_interface_1 = require("../../domain/repositories/model.interface");
const extension_interface_1 = require("../../domain/repositories/extension.interface");
const rxjs_1 = require("rxjs");
const axios_1 = require("@nestjs/axios");
const cortex_1 = require("../../infrastructure/constants/cortex");
const file_manager_service_1 = require("../../infrastructure/services/file-manager/file-manager.service");
const engine_interface_1 = require("../../infrastructure/commanders/types/engine.interface");
let ChatUsecases = class ChatUsecases {
    constructor(modelRepository, extensionRepository, telemetryUseCases, httpService, fileService) {
        this.modelRepository = modelRepository;
        this.extensionRepository = extensionRepository;
        this.telemetryUseCases = telemetryUseCases;
        this.httpService = httpService;
        this.fileService = fileService;
    }
    async inference(createChatDto, headers) {
        var _a;
        const { model: modelId } = createChatDto;
        const model = await this.modelRepository.findOne(modelId);
        if (!model) {
            throw new model_not_found_exception_1.ModelNotFoundException(modelId);
        }
        const engine = (await this.extensionRepository.findOne((_a = model.engine) !== null && _a !== void 0 ? _a : engine_interface_1.Engines.llamaCPP));
        if (engine == null) {
            throw new Error(`No engine found with name: ${model.engine}`);
        }
        try {
            return await engine.inference(createChatDto, headers);
        }
        catch (error) {
            await this.telemetryUseCases.createCrashReport(error, telemetry_interface_1.TelemetrySource.CORTEX_CPP);
            throw error;
        }
    }
    async embeddings(dto) {
        const configs = await this.fileService.getConfig();
        return (0, rxjs_1.firstValueFrom)(this.httpService.post((0, cortex_1.CORTEX_CPP_EMBEDDINGS_URL)(configs.cortexCppHost, configs.cortexCppPort), dto, {
            headers: {
                'Content-Type': 'application/json',
                'Accept-Encoding': 'gzip',
            },
        })).then((res) => res.data);
    }
};
exports.ChatUsecases = ChatUsecases;
exports.ChatUsecases = ChatUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [model_interface_1.ModelRepository,
        extension_interface_1.ExtensionRepository,
        telemetry_usecases_1.TelemetryUsecases,
        axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], ChatUsecases);
//# sourceMappingURL=chat.usecases.js.map