"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CortexUsecases = void 0;
const common_1 = require("@nestjs/common");
const child_process_1 = require("child_process");
const path_1 = require("path");
const axios_1 = require("@nestjs/axios");
const node_fs_1 = require("node:fs");
const rxjs_1 = require("rxjs");
const file_manager_service_1 = require("../../infrastructure/services/file-manager/file-manager.service");
const cortex_1 = require("../../infrastructure/constants/cortex");
const fs_1 = require("fs");
let CortexUsecases = class CortexUsecases {
    constructor(httpService, fileManagerService) {
        this.httpService = httpService;
        this.fileManagerService = fileManagerService;
        this.cortexBinaryName = `cortex-cpp${process.platform === 'win32' ? '.exe' : ''}`;
    }
    async startCortex() {
        const configs = await this.fileManagerService.getConfig();
        const host = configs.cortexCppHost;
        const port = configs.cortexCppPort;
        if (this.cortexProcess || (await this.healthCheck(host, port))) {
            return {
                message: 'Cortex is already running',
                status: 'success',
            };
        }
        const args = ['1', host, `${port}`];
        const dataFolderPath = await this.fileManagerService.getDataFolderPath();
        const cortexCppFolderPath = (0, path_1.join)(dataFolderPath, 'cortex-cpp');
        const cortexCppPath = (0, path_1.join)(cortexCppFolderPath, this.cortexBinaryName);
        if (!(0, node_fs_1.existsSync)(cortexCppPath)) {
            throw new Error('The engine is not available, please run "cortex init".');
        }
        const cortexCPPPath = (0, path_1.join)(await this.fileManagerService.getDataFolderPath(), 'cortex-cpp');
        const writer = (0, fs_1.openSync)(await this.fileManagerService.getLogPath(), 'a+');
        this.cortexProcess = (0, child_process_1.spawn)(cortexCppPath, args, {
            detached: true,
            cwd: cortexCppFolderPath,
            stdio: [0, writer, writer],
            env: {
                ...process.env,
                CUDA_VISIBLE_DEVICES: '0',
                PATH: (process.env.PATH || '').concat(path_1.delimiter, cortexCPPPath),
                LD_LIBRARY_PATH: (process.env.LD_LIBRARY_PATH || '').concat(path_1.delimiter, cortexCPPPath),
            },
        });
        return new Promise((resolve, reject) => {
            const interval = setInterval(() => {
                this.healthCheck(host, port)
                    .then(() => {
                    clearInterval(interval);
                    resolve({
                        message: 'Cortex started successfully',
                        status: 'success',
                    });
                })
                    .catch(reject);
            }, 1000);
        }).then((res) => {
            this.fileManagerService.writeConfigFile({
                ...configs,
                cortexCppHost: host,
                cortexCppPort: port,
            });
            return res;
        });
    }
    async stopCortex() {
        var _a;
        const configs = await this.fileManagerService.getConfig();
        try {
            await (0, rxjs_1.firstValueFrom)(this.httpService.delete((0, cortex_1.CORTEX_CPP_PROCESS_DESTROY_URL)(configs.cortexCppHost, configs.cortexCppPort)));
        }
        catch (err) {
            console.error(err.response.data);
        }
        finally {
            (_a = this.cortexProcess) === null || _a === void 0 ? void 0 : _a.kill();
            return {
                message: 'Cortex stopped successfully',
                status: 'success',
            };
        }
    }
    async stopServe() {
        return fetch((0, cortex_1.CORTEX_JS_STOP_API_SERVER_URL)(), {
            method: 'DELETE',
        })
            .then(() => { })
            .catch(() => { });
    }
    healthCheck(host, port) {
        return fetch((0, cortex_1.CORTEX_CPP_HEALTH_Z_URL)(host, port))
            .then((res) => {
            if (res.ok) {
                return true;
            }
            return false;
        })
            .catch(() => false);
    }
};
exports.CortexUsecases = CortexUsecases;
exports.CortexUsecases = CortexUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService,
        file_manager_service_1.FileManagerService])
], CortexUsecases);
//# sourceMappingURL=cortex.usecases.js.map