import { CreateModelDto } from '@/infrastructure/dtos/models/create-model.dto';
import { UpdateModelDto } from '@/infrastructure/dtos/models/update-model.dto';
import { Model, ModelSettingParams } from '@/domain/models/model.interface';
import { StartModelSuccessDto } from '@/infrastructure/dtos/models/start-model-success.dto';
import { ExtensionRepository } from '@/domain/repositories/extension.interface';
import { FileManagerService } from '@/infrastructure/services/file-manager/file-manager.service';
import { TelemetryUsecases } from '../telemetry/telemetry.usecases';
import { ModelRepository } from '@/domain/repositories/model.interface';
import { HuggingFaceModelVersion, HuggingFaceRepoData, HuggingFaceRepoSibling } from '@/domain/models/huggingface.interface';
import { EventEmitter2 } from '@nestjs/event-emitter';
import { ModelId, ModelStatus } from '@/domain/models/model.event';
import { DownloadManagerService } from '@/infrastructure/services/download-manager/download-manager.service';
import { ContextService } from '@/infrastructure/services/context/context.service';
export declare class ModelsUsecases {
    private readonly modelRepository;
    private readonly extensionRepository;
    private readonly fileManagerService;
    private readonly downloadManagerService;
    private readonly telemetryUseCases;
    private readonly contextService;
    private readonly eventEmitter;
    constructor(modelRepository: ModelRepository, extensionRepository: ExtensionRepository, fileManagerService: FileManagerService, downloadManagerService: DownloadManagerService, telemetryUseCases: TelemetryUsecases, contextService: ContextService, eventEmitter: EventEmitter2);
    private activeModelStatuses;
    create(createModelDto: CreateModelDto): Promise<void>;
    findAll(): Promise<Model[]>;
    findOne(model: string): Promise<Model | null>;
    getModelOrThrow(id: string): Promise<Model>;
    update(id: string, updateModelDto: UpdateModelDto): Promise<void>;
    remove(id: string): Promise<{
        message: string;
        modelId: string;
    } | undefined>;
    startModel(modelId: string, settings?: ModelSettingParams): Promise<StartModelSuccessDto>;
    stopModel(modelId: string): Promise<StartModelSuccessDto>;
    abortDownloadModel(downloadId: string): Promise<void>;
    pullModel(modelId: string, inSequence?: boolean, selection?: (siblings: HuggingFaceRepoSibling[]) => Promise<HuggingFaceRepoSibling>): Promise<void>;
    populateHuggingFaceModel(modelId: string, modelVersion: HuggingFaceModelVersion): Promise<void>;
    fetchModelMetadata(modelId: string): Promise<HuggingFaceRepoData>;
    getModelStatuses(): Record<ModelId, ModelStatus>;
    private validFileDownload;
}
