"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelsUsecases = void 0;
const ora_1 = __importDefault(require("ora"));
const common_1 = require("@nestjs/common");
const model_not_found_exception_1 = require("../../infrastructure/exception/model-not-found.exception");
const path_1 = require("path");
const fs_1 = require("fs");
const extension_interface_1 = require("../../domain/repositories/extension.interface");
const normalize_model_id_1 = require("../../utils/normalize-model-id");
const file_manager_service_1 = require("../../infrastructure/services/file-manager/file-manager.service");
const axios_1 = require("axios");
const telemetry_usecases_1 = require("../telemetry/telemetry.usecases");
const telemetry_interface_1 = require("../../domain/telemetry/telemetry.interface");
const model_interface_1 = require("../../domain/repositories/model.interface");
const model_parameter_parser_1 = require("../../utils/model-parameter.parser");
const huggingface_1 = require("../../utils/huggingface");
const download_interface_1 = require("../../domain/models/download.interface");
const event_emitter_1 = require("@nestjs/event-emitter");
const download_manager_service_1 = require("../../infrastructure/services/download-manager/download-manager.service");
const context_service_1 = require("../../infrastructure/services/context/context.service");
const engine_interface_1 = require("../../infrastructure/commanders/types/engine.interface");
const js_yaml_1 = require("js-yaml");
const app_path_1 = require("../../utils/app-path");
let ModelsUsecases = class ModelsUsecases {
    constructor(modelRepository, extensionRepository, fileManagerService, downloadManagerService, telemetryUseCases, contextService, eventEmitter) {
        this.modelRepository = modelRepository;
        this.extensionRepository = extensionRepository;
        this.fileManagerService = fileManagerService;
        this.downloadManagerService = downloadManagerService;
        this.telemetryUseCases = telemetryUseCases;
        this.contextService = contextService;
        this.eventEmitter = eventEmitter;
        this.activeModelStatuses = {};
    }
    async create(createModelDto) {
        const { model: modelId, owned_by } = createModelDto;
        const model = {
            ...createModelDto,
            id: modelId,
            created: Date.now(),
            object: 'model',
            owned_by: owned_by !== null && owned_by !== void 0 ? owned_by : '',
        };
        await this.modelRepository.create(model);
    }
    async findAll() {
        return this.modelRepository.findAll();
    }
    async findOne(model) {
        this.contextService.set('modelId', model);
        return this.modelRepository.findOne(model);
    }
    async getModelOrThrow(id) {
        const model = await this.findOne(id);
        if (!model) {
            throw new model_not_found_exception_1.ModelNotFoundException(id);
        }
        return model;
    }
    update(id, updateModelDto) {
        return this.modelRepository.update(id, updateModelDto);
    }
    async remove(id) {
        const modelsContainerDir = await this.fileManagerService.getModelsPath();
        if (!(0, fs_1.existsSync)(modelsContainerDir)) {
            return;
        }
        const modelFolder = (0, path_1.join)(modelsContainerDir, (0, normalize_model_id_1.normalizeModelId)(id));
        return this.modelRepository
            .remove(id)
            .then(() => (0, fs_1.existsSync)(modelFolder) && (0, fs_1.rmSync)(modelFolder, { recursive: true }))
            .then(() => {
            const modelEvent = {
                model: id,
                event: 'model-deleted',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
        })
            .then(() => {
            return {
                message: 'Model removed successfully',
                modelId: id,
            };
        });
    }
    async startModel(modelId, settings) {
        var _a, _b;
        const model = await this.getModelOrThrow(modelId);
        const engine = (await this.extensionRepository.findOne((_a = model.engine) !== null && _a !== void 0 ? _a : engine_interface_1.Engines.llamaCPP));
        if (!engine) {
            return {
                message: 'No extension handler found for model',
                modelId,
            };
        }
        const loadingModelSpinner = (0, ora_1.default)('Loading model...').start();
        this.activeModelStatuses[modelId] = {
            model: modelId,
            status: 'starting',
            metadata: {},
        };
        const modelEvent = {
            model: modelId,
            event: 'starting',
            metadata: {},
        };
        this.eventEmitter.emit('model.event', modelEvent);
        const parser = new model_parameter_parser_1.ModelParameterParser();
        const loadModelSettings = {
            ctx_len: 4096,
            ngl: 100,
            ...((model === null || model === void 0 ? void 0 : model.files) &&
                Array.isArray(model.files) &&
                !('llama_model_path' in model) && {
                llama_model_path: model.files[0],
                model_path: model.files[0],
            }),
            engine: (_b = model.engine) !== null && _b !== void 0 ? _b : engine_interface_1.Engines.llamaCPP,
            ...parser.parseModelEngineSettings(model),
            ...parser.parseModelEngineSettings(settings !== null && settings !== void 0 ? settings : {}),
        };
        return engine
            .loadModel(model, loadModelSettings)
            .then(() => {
            this.activeModelStatuses[modelId] = {
                model: modelId,
                status: 'started',
                metadata: {},
            };
            const modelEvent = {
                model: modelId,
                event: 'started',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
        })
            .then(() => {
            loadingModelSpinner.succeed('Model loaded');
            return {
                message: 'Model loaded successfully',
                modelId,
            };
        })
            .catch(async (e) => {
            delete this.activeModelStatuses[modelId];
            const modelEvent = {
                model: modelId,
                event: 'starting-failed',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
            if (e.code === axios_1.AxiosError.ERR_BAD_REQUEST) {
                loadingModelSpinner.succeed('Model loaded');
                return {
                    message: 'Model already loaded',
                    modelId,
                };
            }
            loadingModelSpinner.fail('Model loading failed');
            await this.telemetryUseCases.createCrashReport(e, telemetry_interface_1.TelemetrySource.CORTEX_CPP);
            throw {
                message: e.message,
                modelId,
            };
        });
    }
    async stopModel(modelId) {
        var _a;
        const model = await this.getModelOrThrow(modelId);
        const engine = (await this.extensionRepository.findOne((_a = model.engine) !== null && _a !== void 0 ? _a : engine_interface_1.Engines.llamaCPP));
        if (!engine) {
            return {
                message: 'No extension handler found for model',
                modelId,
            };
        }
        this.activeModelStatuses[modelId] = {
            model: modelId,
            status: 'stopping',
            metadata: {},
        };
        const modelEvent = {
            model: modelId,
            event: 'stopping',
            metadata: {},
        };
        this.eventEmitter.emit('model.event', modelEvent);
        return engine
            .unloadModel(modelId)
            .then(() => {
            delete this.activeModelStatuses[modelId];
            const modelEvent = {
                model: modelId,
                event: 'stopped',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
        })
            .then(() => ({
            message: 'Model is stopped',
            modelId,
        }))
            .catch(async (e) => {
            const modelEvent = {
                model: modelId,
                event: 'stopping-failed',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
            await this.telemetryUseCases.createCrashReport(e, telemetry_interface_1.TelemetrySource.CORTEX_CPP);
            return {
                message: e.message,
                modelId,
            };
        });
    }
    async abortDownloadModel(downloadId) {
        this.downloadManagerService.abortDownload(downloadId);
    }
    async pullModel(modelId, inSequence = true, selection) {
        const existingModel = await this.findOne(modelId);
        if ((0, normalize_model_id_1.isLocalModel)(existingModel === null || existingModel === void 0 ? void 0 : existingModel.files)) {
            throw new common_1.BadRequestException('Model already exists');
        }
        const modelsContainerDir = await this.fileManagerService.getModelsPath();
        if (!(0, fs_1.existsSync)(modelsContainerDir)) {
            (0, fs_1.mkdirSync)(modelsContainerDir, { recursive: true });
        }
        const modelFolder = (0, path_1.join)(modelsContainerDir, (0, normalize_model_id_1.normalizeModelId)(modelId));
        await fs_1.promises.mkdir(modelFolder, { recursive: true }).catch(() => { });
        let files = (await (0, huggingface_1.fetchJanRepoData)(modelId)).siblings;
        if (modelId.includes('/') && selection && files.length) {
            files = [await selection(files)];
        }
        const toDownloads = files
            .filter((e) => this.validFileDownload(e))
            .reduce((acc, file) => {
            if (file.downloadUrl)
                acc[file.downloadUrl] = (0, path_1.join)(modelFolder, file.rfilename);
            return acc;
        }, {});
        return this.downloadManagerService.submitDownloadRequest(modelId, modelId, download_interface_1.DownloadType.Model, toDownloads, async () => {
            var _a, _b, _c, _d;
            const uploadModelMetadataSpiner = (0, ora_1.default)('Updating model metadata...').start();
            if ((0, fs_1.existsSync)((0, path_1.join)(modelFolder, 'model.yml'))) {
                const model = (0, js_yaml_1.load)((0, fs_1.readFileSync)((0, path_1.join)(modelFolder, 'model.yml'), 'utf-8'));
                if (model.engine === engine_interface_1.Engines.llamaCPP && model.files) {
                    const fileUrl = (0, path_1.join)(await this.fileManagerService.getModelsPath(), (0, normalize_model_id_1.normalizeModelId)(modelId), (0, app_path_1.llamaModelFile)(model.files));
                    model.files = [fileUrl];
                    model.name = modelId.replace(':default', '');
                }
                else if (model.engine === engine_interface_1.Engines.llamaCPP) {
                    model.files = [
                        (0, path_1.join)(await this.fileManagerService.getModelsPath(), (0, normalize_model_id_1.normalizeModelId)(modelId), (0, path_1.basename)((_b = (_a = files.find((e) => e.rfilename.endsWith('.gguf'))) === null || _a === void 0 ? void 0 : _a.rfilename) !== null && _b !== void 0 ? _b : files[0].rfilename)),
                    ];
                }
                else {
                    model.files = [modelFolder];
                }
                model.model = modelId;
                if (!(await this.findOne(modelId)))
                    await this.create(model);
            }
            else {
                const data = await this.fetchModelMetadata(modelId);
                await this.populateHuggingFaceModel(modelId, files[0]);
                const model = await this.findOne(modelId);
                if (model) {
                    const fileUrl = (0, path_1.join)(await this.fileManagerService.getModelsPath(), (0, normalize_model_id_1.normalizeModelId)(modelId), (0, path_1.basename)((_d = (_c = files.find((e) => e.rfilename.endsWith('.gguf'))) === null || _c === void 0 ? void 0 : _c.rfilename) !== null && _d !== void 0 ? _d : files[0].rfilename));
                    await this.update(modelId, {
                        files: [fileUrl],
                        name: modelId.replace(':default', ''),
                    });
                }
            }
            uploadModelMetadataSpiner.succeed('Model metadata updated');
            const modelEvent = {
                model: modelId,
                event: 'model-downloaded',
                metadata: {},
            };
            this.eventEmitter.emit('model.event', modelEvent);
        }, inSequence);
    }
    async populateHuggingFaceModel(modelId, modelVersion) {
        var _a;
        if (!modelVersion)
            throw 'No expected quantization found';
        const tokenizer = await (0, huggingface_1.getHFModelMetadata)(modelVersion.downloadUrl);
        const stopWords = (tokenizer === null || tokenizer === void 0 ? void 0 : tokenizer.stopWord) ? [tokenizer.stopWord] : [];
        const model = {
            files: [(_a = modelVersion.downloadUrl) !== null && _a !== void 0 ? _a : ''],
            model: modelId,
            name: modelId,
            prompt_template: tokenizer === null || tokenizer === void 0 ? void 0 : tokenizer.promptTemplate,
            stop: stopWords,
            stream: true,
            max_tokens: 4098,
            frequency_penalty: 0.7,
            presence_penalty: 0.7,
            temperature: 0.7,
            top_p: 0.7,
            ctx_len: 4096,
            ngl: 100,
            engine: engine_interface_1.Engines.llamaCPP,
        };
        if (!(await this.findOne(modelId)))
            await this.create(model);
    }
    fetchModelMetadata(modelId) {
        if (modelId.includes('/'))
            return (0, huggingface_1.fetchHuggingFaceRepoData)(modelId);
        else
            return (0, huggingface_1.fetchJanRepoData)(modelId);
    }
    getModelStatuses() {
        return this.activeModelStatuses;
    }
    validFileDownload(file) {
        return !!file.downloadUrl;
    }
};
exports.ModelsUsecases = ModelsUsecases;
exports.ModelsUsecases = ModelsUsecases = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [model_interface_1.ModelRepository,
        extension_interface_1.ExtensionRepository,
        file_manager_service_1.FileManagerService,
        download_manager_service_1.DownloadManagerService,
        telemetry_usecases_1.TelemetryUsecases,
        context_service_1.ContextService,
        event_emitter_1.EventEmitter2])
], ModelsUsecases);
//# sourceMappingURL=models.usecases.js.map