import { TelemetryRepository } from '@/domain/repositories/telemetry.interface';
import { BenchmarkHardware, EventAttributes, Telemetry, TelemetryAnonymized, TelemetrySource } from '@/domain/telemetry/telemetry.interface';
import { ModelStat } from '@/infrastructure/commanders/types/model-stat.interface';
import { ContextService } from '@/infrastructure/services/context/context.service';
import { HttpException } from '@nestjs/common';
export declare class TelemetryUsecases {
    private readonly telemetryRepository;
    private readonly contextService;
    private readonly crashReports;
    private readonly maxSize;
    private metricQueue;
    private readonly maxQueueSize;
    private readonly flushInterval;
    private interval;
    private lastActiveAt?;
    constructor(telemetryRepository: TelemetryRepository, contextService: ContextService);
    createCrashReport(error: HttpException | Error, source: TelemetrySource): Promise<void>;
    sendCrashReport(): Promise<void>;
    readCrashReports(callback: (Telemetry: Telemetry) => void): Promise<void>;
    private buildCrashReport;
    private isCrashReportEnabled;
    private isMetricsEnabled;
    private isBenchmarkEnabled;
    private catchException;
    initInterval(): Promise<void>;
    sendEvent(events: EventAttributes[], source: TelemetrySource): Promise<void>;
    sendActivationEvent(source: TelemetrySource): Promise<void>;
    addEventToQueue(event: EventAttributes): Promise<void>;
    private flushMetricQueue;
    private flushMetricQueueInterval;
    updateAnonymousData(lastActiveAt?: string | null): Promise<TelemetryAnonymized | null>;
    sendBenchmarkEvent({ hardware, results, metrics, model, }: {
        hardware: BenchmarkHardware;
        results: any;
        metrics: any;
        model: ModelStat;
    }): Promise<void>;
}
