"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThreadsUsecases = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("typeorm");
const uuid_1 = require("uuid");
const page_dto_1 = require("../../infrastructure/dtos/page.dto");
const ulid_1 = require("ulid");
let ThreadsUsecases = class ThreadsUsecases {
    constructor(threadRepository, messageRepository) {
        this.threadRepository = threadRepository;
        this.messageRepository = messageRepository;
    }
    async create(createThreadDto) {
        const id = (0, uuid_1.v4)();
        const { assistants } = createThreadDto;
        const assistantEntity = assistants.map((assistant) => {
            var _a, _b;
            const entity = {
                ...assistant,
                response_format: null,
                tool_resources: null,
                top_p: (_a = assistant.top_p) !== null && _a !== void 0 ? _a : null,
                temperature: (_b = assistant.temperature) !== null && _b !== void 0 ? _b : null,
            };
            return entity;
        });
        const thread = {
            id,
            assistants: assistantEntity,
            object: 'thread',
            created_at: Date.now(),
            title: 'New Thread',
            tool_resources: null,
            metadata: null,
        };
        await this.threadRepository.insert(thread);
        return thread;
    }
    async findAll() {
        return this.threadRepository.find({
            order: {
                created_at: 'DESC',
            },
        });
    }
    async getMessagesOfThread(threadId, limit, order, after, before, runId) {
        var _a, _b, _c, _d;
        await this.getThreadOrThrow(threadId);
        const queryBuilder = this.messageRepository.createQueryBuilder();
        const normalizedOrder = order === 'asc' ? 'ASC' : 'DESC';
        queryBuilder
            .where('thread_id = :id', { id: threadId })
            .orderBy('created_at', normalizedOrder)
            .take(limit + 1);
        if (after) {
            queryBuilder.andWhere('id > :after', { after });
        }
        if (before) {
            queryBuilder.andWhere('id < :before', { before });
        }
        const { entities: messages } = await queryBuilder.getRawAndEntities();
        let hasMore = false;
        if (messages.length > limit) {
            hasMore = true;
            messages.pop();
        }
        const firstId = (_b = (_a = messages[0]) === null || _a === void 0 ? void 0 : _a.id) !== null && _b !== void 0 ? _b : undefined;
        const lastId = (_d = (_c = messages[messages.length - 1]) === null || _c === void 0 ? void 0 : _c.id) !== null && _d !== void 0 ? _d : undefined;
        return new page_dto_1.PageDto(messages, hasMore, firstId, lastId);
    }
    async createMessageInThread(threadId, createMessageDto) {
        const thread = await this.getThreadOrThrow(threadId);
        const assistantId = thread.assistants[0].id;
        const messageContent = {
            type: 'text',
            text: {
                annotations: [],
                value: createMessageDto.content,
            },
        };
        const message = {
            id: (0, ulid_1.ulid)(),
            object: 'thread.message',
            thread_id: threadId,
            assistant_id: assistantId,
            created_at: Date.now(),
            status: 'completed',
            role: createMessageDto.role,
            content: [messageContent],
            metadata: null,
            run_id: null,
            completed_at: null,
            incomplete_details: null,
            attachments: [],
            incomplete_at: null,
        };
        await this.messageRepository.insert(message);
        return message;
    }
    async updateMessage(threadId, messageId, updateMessageDto) {
        await this.getThreadOrThrow(threadId);
        await this.messageRepository.update(messageId, updateMessageDto);
        return this.messageRepository.findOne({
            where: {
                id: messageId,
            },
        });
    }
    async getThreadOrThrow(threadId) {
        const thread = await this.findOne(threadId);
        if (!thread) {
            throw new common_1.NotFoundException(`Thread with id ${threadId} not found`);
        }
        return thread;
    }
    async getMessageOrThrow(messageId) {
        const message = await this.messageRepository.findOne({
            where: {
                id: messageId,
            },
        });
        if (!message) {
            throw new common_1.NotFoundException(`Message with id ${messageId} not found`);
        }
        return message;
    }
    findOne(id) {
        return this.threadRepository.findOne({ where: { id } });
    }
    async update(id, updateThreadDto) {
        var _a, _b;
        const assistantEntities = (_b = (_a = updateThreadDto.assistants) === null || _a === void 0 ? void 0 : _a.map((assistant) => {
            var _a, _b;
            const entity = {
                ...assistant,
                name: assistant.name,
                response_format: null,
                tool_resources: null,
                top_p: (_a = assistant.top_p) !== null && _a !== void 0 ? _a : null,
                temperature: (_b = assistant.temperature) !== null && _b !== void 0 ? _b : null,
            };
            return entity;
        })) !== null && _b !== void 0 ? _b : [];
        const entity = {
            ...updateThreadDto,
            assistants: assistantEntities,
        };
        return this.threadRepository.update(id, entity);
    }
    remove(id) {
        this.threadRepository.delete(id);
    }
    async deleteMessage(_threadId, messageId) {
        await this.getMessageOrThrow(messageId);
        await this.messageRepository.delete(messageId);
        return {
            id: messageId,
            object: 'thread.message.deleted',
            deleted: true,
        };
    }
    async retrieveMessage(_threadId, messageId) {
        return this.getMessageOrThrow(messageId);
    }
    async clean(threadId) {
        await this.getThreadOrThrow(threadId);
        await this.messageRepository.delete({ thread_id: threadId });
    }
};
exports.ThreadsUsecases = ThreadsUsecases;
exports.ThreadsUsecases = ThreadsUsecases = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)('THREAD_REPOSITORY')),
    __param(1, (0, common_1.Inject)('MESSAGE_REPOSITORY')),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        typeorm_1.Repository])
], ThreadsUsecases);
//# sourceMappingURL=threads.usecases.js.map