"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkModelCompatibility = void 0;
const cortex_1 = require("../infrastructure/constants/cortex");
const cuda_1 = require("./cuda");
const checkModelCompatibility = async (modelId, spinner) => {
    var _a, _b;
    function log(message) {
        if (spinner) {
            spinner.fail(message);
        }
        else {
            console.error(message);
        }
    }
    if (modelId.includes('onnx') && process.platform !== 'win32') {
        log('The ONNX engine does not support this OS yet.');
        process.exit(1);
    }
    if (modelId.includes('tensorrt-llm')) {
        if (process.platform === 'darwin') {
            log('Tensorrt-LLM models are not supported on this OS');
            process.exit(1);
        }
        try {
            const version = await (0, cuda_1.getCudaVersion)();
            const [currentMajor, currentMinor] = version.split('.').map(Number);
            const [requiredMajor, requiredMinor] = cortex_1.MIN_CUDA_VERSION.split('.').map(Number);
            const isMatchRequired = currentMajor > requiredMajor || (currentMajor === requiredMajor && currentMinor >= requiredMinor);
            if (!isMatchRequired) {
                log(`CUDA version ${version} is not compatible with TensorRT-LLM models. Required version: ${cortex_1.MIN_CUDA_VERSION}`);
                process.exit(1);
            }
        }
        catch (e) {
            console.error((_a = e.message) !== null && _a !== void 0 ? _a : e);
            log((_b = e.message) !== null && _b !== void 0 ? _b : e);
            process.exit(1);
        }
    }
};
exports.checkModelCompatibility = checkModelCompatibility;
//# sourceMappingURL=model-check.js.map