"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModelParameterParser = void 0;
class ModelParameterParser {
    constructor() {
        this.modelSettingParamTypes = {
            prompt_template: 'string',
            ctx_len: 'number',
            ngl: 'number',
            n_parallel: 'number',
            cpu_threads: 'number',
            llama_model_path: 'string',
            mmproj: 'string',
            cont_batching: 'boolean',
            pre_prompt: 'string',
        };
        this.modelRuntimeParamTypes = {
            temperature: 'number',
            top_k: 'number',
            top_p: 'number',
            stream: 'boolean',
            max_tokens: 'number',
            stop: 'string[]',
            frequency_penalty: 'number',
            presence_penalty: 'number',
        };
    }
    parseModelInferenceParams(model) {
        const inferenceParams = structuredClone(model);
        return Object.keys(inferenceParams).reduce((acc, key) => {
            if (!this.isModelRuntimeParam(key)) {
                delete acc[key];
            }
            return acc;
        }, inferenceParams);
    }
    parseModelEngineSettings(model) {
        const engineSettings = structuredClone(model);
        return Object.keys(engineSettings).reduce((acc, key) => {
            if (!this.isModelSettingParam(key)) {
                delete acc[key];
            }
            return acc;
        }, engineSettings);
    }
    isModelSettingParam(key) {
        return key in this.modelSettingParamTypes;
    }
    isModelRuntimeParam(key) {
        return key in this.modelRuntimeParamTypes;
    }
}
exports.ModelParameterParser = ModelParameterParser;
//# sourceMappingURL=model-parameter.parser.js.map